/***********************************************
 * Licensed Materials - Property of IBM
 *
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */

package com.ibm.websphere.icp.insurance.life.reference.util;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

import com.ibm.websphere.fabric.industry.support.util.SDOTransformationUtils;
import commonj.sdo.DataObject;

/**
 * Helper class for assignment and mapping between various requests and responses.
 * 
 * @author admin
 */
public final class DataAssignmentHelper {
	
	    
	/**
     * Private Constructor. 
     */
    private DataAssignmentHelper() {
    }

	/**
	 * @param TXLife_Type
	 * @param customerSearch
	 */
	public static void assignSearchCustomerToPerformFinancialPlanning(DataObject TXLife_Type, DataObject customerSearch) {
		BOHelper.debug("inside assignSearchCustomerToPerformFinancialPlanning");
		//TXLife_Type = BOHelper.createCustomerTXLifeRequest(TXLife_Type);
		BOHelper.debug(customerSearch);
		if (customerSearch.getDataObject("ClientInfo") != null){
			
			
			DataObject clientInfoBO = customerSearch.getDataObject("ClientInfo");
			if(clientInfoBO.getString("FirstName") != null || clientInfoBO.getString("LastName") != null || clientInfoBO.getString("Zip") !=null
					|| clientInfoBO.getString("City") !=null || clientInfoBO.getString("Address1") !=null ||clientInfoBO.getString("Address2")!=null
					|| clientInfoBO.getString("State")!=null ||clientInfoBO.getString("DOB")!=null || clientInfoBO.getString("Suffix")!= null || clientInfoBO.getString("Gender") !=null){
				
				//TXLife_Type
				DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type, false, InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX); 

				List partyList = new ArrayList();
				//Person
				DataObject personDO = BOHelper.createDataObject(BOHelper.CUSTOMER_OLIFE_NS, "Person_Type");
				personDO.setString("FirstName",clientInfoBO.getString("FirstName"));
				personDO.setString("LastName", clientInfoBO.getString("LastName"));
				personDO.set("BirthDate", clientInfoBO.getString("DOB") );
				personDO.createDataObject("Gender").set(0, clientInfoBO.getString("Gender"));
				//Address
				DataObject addressDO = BOHelper.createDataObject(BOHelper.EXTENSIONS_NS, "Address_Type");
				addressDO.setString("City", clientInfoBO.getString("City"));
				addressDO.setString("Zip", clientInfoBO.getString("Zip"));
				addressDO.setString("Line1", clientInfoBO.getString("Address1"));
				addressDO.setString("Line2", clientInfoBO.getString("Address2"));
				DataObject addressStateDO = BOHelper.boFactory.create(BOHelper.CUSTOMER_OLIFE_NS, "AddressStateTC_Type");
				addressStateDO.set(0, clientInfoBO.getString("State"));
				addressDO.set("AddressStateTC", addressStateDO);
				addressDO.set("State", clientInfoBO.getString("State"));
				//Party
				DataObject partyDO = BOHelper.boFactory.create(BOHelper.EXTENSIONS_NS, "CustomerParty_Type"); 
				partyDO.set("Suffix", clientInfoBO.getString("Suffix"));
				partyDO.set("Person", personDO);
				ArrayList AddList = new ArrayList();
				AddList.add(addressDO);
				partyDO.setList("Address", AddList);
				partyList.add(partyDO);
				//Olife set
				OLife.setList("Party", partyList);
				BOHelper.debug("inside if loop---------2");
				BOHelper.debug(OLife);

			}
		}
		BOHelper.debug(TXLife_Type);		
		BOHelper.debug("exit:- assignSearchCustomerToPerformFinancialPlanning");
	}

	/**
	 * @param SelectCustomer
	 * @param TXLife_Type_Response
	 */
	public static void assignTXLife_ResponseToSelectCustomer(DataObject SelectCustomer,DataObject TXLife_Type_Response) {
		try{
		BOHelper.debug("entry:- assignTXLife_ResponseToSelectCustomer");	
		BOHelper.debug(TXLife_Type_Response);
		DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type_Response, true, InsuranceConstants.CUSTOMER_OLIFE_INDEX); 

		//Olife is of Customer_lib OLife_Type
		BOHelper.debug("entry:- assignTXLife_ResponseToSelectCustomer---2");
		
		List partyList = OLife.getList("Party");
		
		List clientInfoList = new ArrayList();
		BOHelper.debug("partyList:: "+ partyList.toString());
        
		for (Iterator iterator = partyList.iterator(); iterator.hasNext();) {
			DataObject clientInfo = BOHelper.createDataObject("http://www.ibm.com/xmlns/prod/websphere/icp/2010/05/insurance/life/extn/schema/ClientInfo","ClientInfo");
			DataObject partyBO = (DataObject) iterator.next();
			String customerid = partyBO.getDataObject("Client").getString("CustomerID");
			//Address
			List addressList = partyBO.getList("Address");
			if (addressList != null & addressList.size()>0) {
				DataObject addressBO = (DataObject)addressList.get(0);
				String address1 = addressBO.getString("Line1");			
				String address2 = addressBO.getString("Line2");
				String city = addressBO.getString("City");
				String state = addressBO.getString("State");
				String zip = addressBO.getString("Zip");
				clientInfo.setString("Zip", zip);
				clientInfo.setString("Address1", address1);
				clientInfo.setString("Address2", address2);
				clientInfo.setString("City", city);
				clientInfo.setString("Unit", addressBO.getString("Unit"));
				clientInfo.setString("State", addressBO.getString("State"));				
			}
			//Person
			DataObject personBO = partyBO.getDataObject("Person");			
			String firstName = (String) personBO.get("FirstName");
			String lastName = (String) personBO.get("LastName");
			Date birthdate =  personBO.getDate("BirthDate");
			String marstatus = personBO.getDataObject("MarStat").getString(0);
			DataObject gender = (DataObject) personBO.get("Gender");
			String suffix = partyBO.getString("Suffix");

			BOHelper.debug("CLient--info");
			clientInfo.setString("FirstName", firstName);
			clientInfo.setString("LastName", lastName);
			clientInfo.setString("SSN", partyBO.getString("SSN"));
			clientInfo.setString("SoldLocation", partyBO.getString("SoldLocation"));
			clientInfo.setString("Age", partyBO.getString("Age"));
			if (partyBO.getDataObject("EMailAddress") != null) {
				clientInfo.setString("Email", partyBO.getDataObject("EMailAddress").getString("AddrLine"));
			}
			clientInfo.setString("Citizenship", partyBO.getString("Citizenship"));
			List pList = partyBO.getList("Phone");
			if(pList != null) {
				if (pList.size()>0) {
					clientInfo.setString("Mobile", ((DataObject)pList.get(0)).getString("DialNumber"));					
				}
				if (pList.size()>1) {
					clientInfo.setString("HomeTelephone", ((DataObject)pList.get(1)).getString("DialNumber"));					
				}				
			}
			clientInfo.setString("Suffix", suffix);
			SimpleDateFormat sdf = new SimpleDateFormat("MM/dd/yyyy");
			clientInfo.set("DOB", sdf.format(birthdate));
			clientInfo.set("Gender", (String)gender.get(0));			
			clientInfo.setString("CustomerId", customerid);
			clientInfoList.add(clientInfo);
		} 

        SelectCustomer.setList("ClientInfo", clientInfoList);
		}catch(Exception e){
			e.printStackTrace();
		}
	}

	/**
	 * @param TXLife_Type_Profile
	 * @param SelectCustomer
	 */
	public static void assignSelectCustomerToCustomerProfile(DataObject TXLife_Type_Profile,DataObject SelectCustomer) {
		try{
		BOHelper.debug("entry:- assignSelectCustomerToCustomerProfile---1");		
		List clientInfoList = SelectCustomer.getList(0);
		DataObject ClientInfoSelected = null;
		for (Iterator iterator = clientInfoList.iterator(); iterator.hasNext();) {
			DataObject clientInfo = (DataObject) iterator.next();
			if (clientInfo != null && 
					clientInfo.getString("SelectedCustomer")!= null && 
					clientInfo.getString("SelectedCustomer").equalsIgnoreCase("true") ){
				ClientInfoSelected = clientInfo;
				break;
			}
		}

		BOHelper.debug(ClientInfoSelected, "inside ClientInfoSelected---------1");
			
		DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type_Profile, false, InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX);
				
		List<DataObject> partyList = new ArrayList<DataObject>();

		BOHelper.debug("*********PARTY************"+ClientInfoSelected.getString("CustomerId"));

		DataObject customerPartyDO =(DataObject)OLife.getList("Party").get(0);

		DataObject clientDO = customerPartyDO.createDataObject("Client", BOHelper.EXTENSIONS_NS, "CustomerClient_Type");
		clientDO.setString("CustomerID",ClientInfoSelected.getString("CustomerId"));
		BOHelper.debug("Monitor Model-----customerPartyDO--------------------");
		BOHelper.debug(customerPartyDO);
		DataObject addressDO = (DataObject) customerPartyDO.getList("Address").get(0);

		DataObject addressStateDO = BOHelper.boFactory.create(BOHelper.CUSTOMER_OLIFE_NS, "AddressStateTC_Type");
		addressStateDO.set(0, ClientInfoSelected.getString("State"));
		addressDO.set("AddressStateTC", addressStateDO);
		customerPartyDO.set("Client",clientDO);
		partyList.add(customerPartyDO);
		BOHelper.debug(OLife);

		OLife.setList("Party", partyList);

		BOHelper.debug("***************************OLIFE**************");
		BOHelper.debug(OLife);
		}
		catch(Exception e){
			e.printStackTrace();
		}
	}
	
	/**
	 * @param TXLife_Type_2
	 * @param SelectCustomer
	 */
	public static void updateResponseToSelectedCustomer(DataObject TXLife_Type_2, DataObject SelectCustomer){
		try{
			
		BOHelper.debug(SelectCustomer, "entry:- updateResponseToSelectedCustomer---1");		
		List clientInfoList = SelectCustomer.getList(0);
		DataObject ClientInfoSelected = null;
		for (Iterator iterator = clientInfoList.iterator(); iterator.hasNext();) {
			DataObject clientInfo = (DataObject) iterator.next();
			if (clientInfo != null && 
					clientInfo.getString("SelectedCustomer")!= null && 
					clientInfo.getString("SelectedCustomer").equalsIgnoreCase("true") ){
				ClientInfoSelected = clientInfo;
				break;
			}
		}
		String selectedCustomerId = ClientInfoSelected.getString("CustomerId");
		BOHelper.debug("selectedCustomerId - "+selectedCustomerId);
		DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type_2, true, InsuranceConstants.CUSTOMER_OLIFE_INDEX); 

		//DataObject customerPartyDO = BOHelper.createDataObject(InsuranceConstants.EXTENSIONS_NS, "CustomerParty_Type");
		List responsepatylist = OLife.getList("Party");
		//DataObject selectedCustomerBO = (DataObject) OLife.getList("Party").get(0);
		DataObject selectedCustomerBO = null;
		List<DataObject> partyList =new ArrayList<DataObject>();
		
		BOHelper.debug(OLife);
		for (Iterator iterator = responsepatylist.iterator(); iterator.hasNext();) {
			DataObject partyBO = (DataObject) iterator.next();
			String customerid = partyBO.getDataObject("Client").getString("CustomerID");
			if (customerid.equalsIgnoreCase(selectedCustomerId)) {
				selectedCustomerBO = partyBO;	
				partyList.add(0,selectedCustomerBO);
				break;
			}
		}
		BOHelper.debug(selectedCustomerBO, "selectedCustomerBO");
		OLife.setList("Party", partyList);		
		BOHelper.debug(TXLife_Type_2, "Final TXLife_Type_2 ~~~~~~~~~~~");
		}
		catch(Exception e){
			e.printStackTrace();
		}
	}
	
	/**
	 * @param CustomerProfile
	 * @param retrieveCustomerProfileResponse
	 * @param TXLife_Type_2
	 */
	public static void assignTXLifeToReviewCustomerProfile(DataObject CustomerProfile, DataObject retrieveCustomerProfileResponse, DataObject TXLife_Type_2) {
		try {
			BOHelper.debug("1--assignTXLifeToReviewCustomerProfile");
			if (retrieveCustomerProfileResponse !=null && 
					retrieveCustomerProfileResponse.getList(InsuranceConstants.TXLIFE_RESPONSE) !=null && 
					retrieveCustomerProfileResponse.getList(InsuranceConstants.TXLIFE_RESPONSE).size()>0) {
				DataObject OLife = BOHelper.getFirstOLifE(retrieveCustomerProfileResponse, true, InsuranceConstants.ORDER_OLIFE_INDEX);
				BOHelper.debug(OLife, "2-OLife-assignTXLifeToReviewCustomerProfile");
				BOHelper.debug(TXLife_Type_2, "2-TXLife_Type_2-assignTXLifeToReviewCustomerProfile");
				
				if (OLife != null) {
					DataObject financialPlanningBO = ((DataObject)OLife.getList("Party").get(0)).getDataObject("Client").getDataObject("FinancialPlaning");
					DataObject OLife_2 = BOHelper.getFirstOLifE(TXLife_Type_2, true, InsuranceConstants.CUSTOMER_OLIFE_INDEX); 
						
					((DataObject)OLife_2.getList("Party").get(0)).getDataObject("Client").setDataObject("FinancialPlaning", financialPlanningBO);
					
					if (financialPlanningBO != null){					
						BOHelper.debug("BEFORE SET :: PrimaryRetirementIncome"+financialPlanningBO.getString("PrimaryRetirementIncome"));
						BOHelper.debug("BEFORE SET :: PrimaryRetirementIncome"+financialPlanningBO.getString("TimeTenYears"));
						CustomerProfile.setString("PrimaryRetirementIncome",financialPlanningBO.getString("PrimaryRetirementIncome"));
						CustomerProfile.setString("SupplementalIncomeRetirement",financialPlanningBO.getString("SupplementalIncomeRetirement"));
						CustomerProfile.setString("AssetAccumulation",financialPlanningBO.getString("AssetAccumulation"));
						CustomerProfile.setString("AccumulationForWealthTransfer",financialPlanningBO.getString("AccumulationForWealthTransfer"));
						CustomerProfile.setString("DeathBenefit",financialPlanningBO.getString("DeathBenefit"));
						CustomerProfile.setString("EnhancedDeathBenefit",financialPlanningBO.getString("EnhancedDeathBenefit"));
						CustomerProfile.setString("SystematicWithdrawalBenifit",financialPlanningBO.getString("SystematicWithdrawalBenifit"));
						CustomerProfile.setString("GuaranteedAccumulationBenefit",financialPlanningBO.getString("GuaranteedAccumulationBenefit"));
						CustomerProfile.setString("GuaranteedIncomeRider",financialPlanningBO.getString("GuaranteedIncomeRider"));
						CustomerProfile.setString("TimeLestshanThreeYears",financialPlanningBO.getString("TimeLestshanThreeYears"));
						CustomerProfile.setString("TimeThreeToFiveYears",financialPlanningBO.getString("TimeThreeToFiveYears"));
						CustomerProfile.setString("TimeFiveToTenYears",financialPlanningBO.getString("TimeFiveToTenYears"));
						CustomerProfile.setString("TimeTenYears",financialPlanningBO.getString("TimeTenYears"));
						CustomerProfile.setString("LifeTime",financialPlanningBO.getString("LifeTime"));
						CustomerProfile.setString("InvestmentExpNone",financialPlanningBO.getString("InvestmentExpNone"));
						CustomerProfile.setString("InvestmentExpLimited",financialPlanningBO.getString("InvestmentExpLimited"));
						CustomerProfile.setString("InvestmentExpExperienced",financialPlanningBO.getString("InvestmentExpExperienced"));
						CustomerProfile.setString("InvestmentExpExtensive",financialPlanningBO.getString("InvestmentExpExtensive"));
						CustomerProfile.setString("InvestLessThan25",financialPlanningBO.getString("InvestLessThan25"));
						CustomerProfile.setString("InvestLessThan75",financialPlanningBO.getString("InvestLessThan75"));
						CustomerProfile.setString("InvestLessThanOneLakh",financialPlanningBO.getString("InvestLessThanOneLakh"));
						CustomerProfile.setString("InvestMoreThanOneLakh",financialPlanningBO.getString("InvestMoreThanOneLakh"));
						CustomerProfile.setString("QualifiedPuchase",financialPlanningBO.getString("QualifiedPuchase"));
						CustomerProfile.setString("QualifiedNonPuchase",financialPlanningBO.getString("QualifiedNonPuchase"));
						CustomerProfile.setString("AddRegularBasis",financialPlanningBO.getString("AddRegularBasis"));
						CustomerProfile.setString("AddirRegularBasis",financialPlanningBO.getString("AddirRegularBasis"));
						CustomerProfile.setString("FundInvestmentExpNone",financialPlanningBO.getString("FundInvestmentExpNone"));
						CustomerProfile.setString("InvestmentExpBonds",financialPlanningBO.getString("InvestmentExpBonds"));
						CustomerProfile.setString("InvestmentExpFutures",financialPlanningBO.getString("InvestmentExpFutures"));
						CustomerProfile.setString("InvestmentExpMutualFunds",financialPlanningBO.getString("InvestmentExpMutualFunds"));
						CustomerProfile.setString("InvestmentExpAnnunities",financialPlanningBO.getString("InvestmentExpAnnunities"));
						CustomerProfile.setString("InvestmentExpCDs",financialPlanningBO.getString("InvestmentExpCDs"));
						CustomerProfile.setString("InvestmentExpEquities",financialPlanningBO.getString("InvestmentExpEquities"));
						CustomerProfile.setString("InvestmentExpOptions",financialPlanningBO.getString("InvestmentExpOptions"));
						CustomerProfile.setString("InvestmentExpIndexedAnnunities",financialPlanningBO.getString("InvestmentExpIndexedAnnunities"));
						CustomerProfile.setString("InvestmentExpFixedAnnunities",financialPlanningBO.getString("InvestmentExpFixedAnnunities"));
						CustomerProfile.setString("InvestmentExpVarLifeIns",financialPlanningBO.getString("InvestmentExpVarLifeIns"));
						CustomerProfile.setString("SponsoredEmployerPrg",financialPlanningBO.getString("SponsoredEmployerPrg"));
						CustomerProfile.setString("NonSponsoredEmployerPrg",financialPlanningBO.getString("NonSponsoredEmployerPrg"));
						CustomerProfile.setString("MaxQualifiedPlan",financialPlanningBO.getString("MaxQualifiedPlan"));
						CustomerProfile.setString("MinQualifiedPlan",financialPlanningBO.getString("MinQualifiedPlan"));
						CustomerProfile.setString("NoQualifiedPlan",financialPlanningBO.getString("NoQualifiedPlan"));
						CustomerProfile.setString("InsHoldingsAmtofLifeIns",financialPlanningBO.getString("InsHoldingsAmtofLifeIns"));
						CustomerProfile.setString("InsHoldingsPlanCashValue",financialPlanningBO.getString("InsHoldingsPlanCashValue"));
						CustomerProfile.setString("InsHoldingsFixedAnnuities",financialPlanningBO.getString("InsHoldingsFixedAnnuities"));
						CustomerProfile.setString("InsHoldingsIndexAnnuities",financialPlanningBO.getString("InsHoldingsIndexAnnuities"));
						CustomerProfile.setString("InsHoldingsVarAnnuities",financialPlanningBO.getString("InsHoldingsVarAnnuities"));
						CustomerProfile.setString("InsHoldingsImmediateAnnuities",financialPlanningBO.getString("InsHoldingsImmediateAnnuities"));
						CustomerProfile.setString("RiskTolConservative",financialPlanningBO.getString("RiskTolConservative"));
						CustomerProfile.setString("RiskTolModConservative",financialPlanningBO.getString("RiskTolModConservative"));
						CustomerProfile.setString("RiskTolModerate",financialPlanningBO.getString("RiskTolModerate"));
						CustomerProfile.setString("RiskTolModAggressive",financialPlanningBO.getString("RiskTolModAggressive"));
						CustomerProfile.setString("RiskTolAggressive",financialPlanningBO.getString("RiskTolAggressive"));
						CustomerProfile.setString("SellInvestment",financialPlanningBO.getString("SellInvestment"));
						CustomerProfile.setString("FluctuationLot",financialPlanningBO.getString("FluctuationLot"));
						CustomerProfile.setString("FluctuationSome",financialPlanningBO.getString("FluctuationSome"));
						CustomerProfile.setString("FluctuationLittle",financialPlanningBO.getString("FluctuationLittle"));
						CustomerProfile.setString("FluctuationNone",financialPlanningBO.getString("FluctuationNone"));
						CustomerProfile.setString("InvestmentObjPOC",financialPlanningBO.getString("InvestmentObjPOC"));
						CustomerProfile.setString("InvestmentObjIncome",financialPlanningBO.getString("InvestmentObjIncome"));
						CustomerProfile.setString("InvestmentObjModGrowth",financialPlanningBO.getString("InvestmentObjModGrowth"));
						CustomerProfile.setString("InvestmentObjGrowth",financialPlanningBO.getString("InvestmentObjGrowth"));
						CustomerProfile.setString("InvestmentObjAggGrowth",financialPlanningBO.getString("InvestmentObjAggGrowth"));
						CustomerProfile.setString("IncomeTaxBracketFifteen",financialPlanningBO.getString("IncomeTaxBracketFifteen"));
						CustomerProfile.setString("IncomeTaxBracketLessThanThirty",financialPlanningBO.getString("IncomeTaxBracketLessThanThirty"));
						CustomerProfile.setString("IncomeTaxBracketMoreThanThirty",financialPlanningBO.getString("IncomeTaxBracketMoreThanThirty"));
						CustomerProfile.setString("IncomeTaxBracketUnsure",financialPlanningBO.getString("IncomeTaxBracketUnsure"));
						CustomerProfile.setString("AnnInclessthanfifty",financialPlanningBO.getString("AnnInclessthanfifty"));
						CustomerProfile.setString("AnnInclessthanOnefifty",financialPlanningBO.getString("AnnInclessthanOnefifty"));
						CustomerProfile.setString("AnnInclessthanTwofifty",financialPlanningBO.getString("AnnInclessthanTwofifty"));
						CustomerProfile.setString("AnnInclmorethantwofifty",financialPlanningBO.getString("AnnInclmorethantwofifty"));
						CustomerProfile.setString("FinacialNeeds",financialPlanningBO.getString("FinacialNeeds"));
						CustomerProfile.setString("FinacialNeedsUnsure",financialPlanningBO.getString("FinacialNeedsUnsure"));
						CustomerProfile.setString("HouseHoldLessThanFiveHundred",financialPlanningBO.getString("HouseHoldLessThanFiveHundred"));
						CustomerProfile.setString("HouseHoldLessThanOneThousand",financialPlanningBO.getString("HouseHoldLessThanOneThousand"));
						CustomerProfile.setString("HouseHoldMoreThanFiveHuundred",financialPlanningBO.getString("HouseHoldMoreThanFiveHuundred"));
						CustomerProfile.setString("EmploymentAnticipated",financialPlanningBO.getString("EmploymentAnticipated"));
						CustomerProfile.setString("EmploymentAnticipatedUnsure",financialPlanningBO.getString("EmploymentAnticipatedUnsure"));
						//CustomerProfile.setString("PremiumAmount",financialPlanningBO.getString("PremiumAmount"));
						//CustomerProfile.setString("InsuredAmount",financialPlanningBO.getString("InsuredAmount"));
					}
				}
			} else {
				BOHelper.debug("NO Customer Profile found--So no data is prepopulated");
			}
		}
		catch (Exception e) {
			e.printStackTrace();
		}		
	}
	
	/**
	 * @param TXLife_Type_2
	 * @param CustomerProfile
	 */
	public static void assignCustomerProfileToTXLife_Type(DataObject TXLife_Type_2, DataObject CustomerProfile) {
		try{
		BOHelper.debug("assignCustomerProfileToTXLife_Type");
		BOHelper.debug("CustomerProfile: "+CustomerProfile);
		BOHelper.debug("TXLife_Type_2: " +TXLife_Type_2);

		if (CustomerProfile!=null) {
			//Financial Planning
			DataObject financialPlanningBO = BOHelper.createDataObject("http://www.ibm.com/xmlns/prod/websphere/icp/2010/05/insurance/life/extn/schema/IRIExtensions","FinancialPlanning_Type");
			financialPlanningBO.setString("PrimaryRetirementIncome", CustomerProfile.getString("PrimaryRetirementIncome"));
			financialPlanningBO.setString("SupplementalIncomeRetirement", CustomerProfile.getString("SupplementalIncomeRetirement"));
			financialPlanningBO.setString("AssetAccumulation", CustomerProfile.getString("AssetAccumulation"));
			financialPlanningBO.setString("AccumulationForWealthTransfer", CustomerProfile.getString("AccumulationForWealthTransfer"));
			financialPlanningBO.setString("DeathBenefit", CustomerProfile.getString("DeathBenefit"));
			financialPlanningBO.setString("EnhancedDeathBenefit", CustomerProfile.getString("EnhancedDeathBenefit"));
			financialPlanningBO.setString("SystematicWithdrawalBenifit", CustomerProfile.getString("SystematicWithdrawalBenifit"));
			financialPlanningBO.setString("GuaranteedAccumulationBenefit", CustomerProfile.getString("GuaranteedAccumulationBenefit"));
			financialPlanningBO.setString("GuaranteedIncomeRider", CustomerProfile.getString("GuaranteedIncomeRider"));
			financialPlanningBO.setString("TimeLestshanThreeYears", CustomerProfile.getString("TimeLestshanThreeYears"));
			financialPlanningBO.setString("TimeThreeToFiveYears", CustomerProfile.getString("TimeThreeToFiveYears"));
			financialPlanningBO.setString("TimeFiveToTenYears", CustomerProfile.getString("TimeFiveToTenYears"));
			financialPlanningBO.setString("TimeTenYears", CustomerProfile.getString("TimeTenYears"));
			financialPlanningBO.setString("LifeTime", CustomerProfile.getString("LifeTime"));
			financialPlanningBO.setString("InvestmentExpNone", CustomerProfile.getString("InvestmentExpNone"));
			financialPlanningBO.setString("InvestmentExpLimited", CustomerProfile.getString("InvestmentExpLimited"));
			financialPlanningBO.setString("InvestmentExpExperienced", CustomerProfile.getString("InvestmentExpExperienced"));
			financialPlanningBO.setString("InvestmentExpExtensive", CustomerProfile.getString("InvestmentExpExtensive"));
			financialPlanningBO.setString("InvestLessThan25", CustomerProfile.getString("InvestLessThan25"));
			financialPlanningBO.setString("InvestLessThan75", CustomerProfile.getString("InvestLessThan75"));
			financialPlanningBO.setString("InvestLessThanOneLakh", CustomerProfile.getString("InvestLessThanOneLakh"));
			financialPlanningBO.setString("InvestMoreThanOneLakh", CustomerProfile.getString("InvestMoreThanOneLakh"));
			financialPlanningBO.setString("QualifiedPuchase", CustomerProfile.getString("QualifiedPuchase"));
			financialPlanningBO.setString("QualifiedNonPuchase", CustomerProfile.getString("QualifiedNonPuchase"));
			financialPlanningBO.setString("AddRegularBasis", CustomerProfile.getString("AddRegularBasis"));
			financialPlanningBO.setString("AddirRegularBasis", CustomerProfile.getString("AddirRegularBasis"));
			financialPlanningBO.setString("FundInvestmentExpNone", CustomerProfile.getString("FundInvestmentExpNone"));
			financialPlanningBO.setString("InvestmentExpBonds", CustomerProfile.getString("InvestmentExpBonds"));
			financialPlanningBO.setString("InvestmentExpFutures", CustomerProfile.getString("InvestmentExpFutures"));
			financialPlanningBO.setString("InvestmentExpMutualFunds", CustomerProfile.getString("InvestmentExpMutualFunds"));
			financialPlanningBO.setString("InvestmentExpAnnunities", CustomerProfile.getString("InvestmentExpAnnunities"));
			financialPlanningBO.setString("InvestmentExpCDs", CustomerProfile.getString("InvestmentExpCDs"));
			financialPlanningBO.setString("InvestmentExpEquities", CustomerProfile.getString("InvestmentExpEquities"));
			financialPlanningBO.setString("InvestmentExpOptions", CustomerProfile.getString("InvestmentExpOptions"));
			financialPlanningBO.setString("InvestmentExpIndexedAnnunities", CustomerProfile.getString("InvestmentExpIndexedAnnunities"));
			financialPlanningBO.setString("InvestmentExpFixedAnnunities", CustomerProfile.getString("InvestmentExpFixedAnnunities"));
			financialPlanningBO.setString("InvestmentExpVarLifeIns", CustomerProfile.getString("InvestmentExpVarLifeIns"));
			financialPlanningBO.setString("SponsoredEmployerPrg", CustomerProfile.getString("SponsoredEmployerPrg"));
			financialPlanningBO.setString("NonSponsoredEmployerPrg", CustomerProfile.getString("NonSponsoredEmployerPrg"));
			financialPlanningBO.setString("MaxQualifiedPlan", CustomerProfile.getString("MaxQualifiedPlan"));
			financialPlanningBO.setString("MinQualifiedPlan", CustomerProfile.getString("MinQualifiedPlan"));
			financialPlanningBO.setString("NoQualifiedPlan", CustomerProfile.getString("NoQualifiedPlan"));
			financialPlanningBO.setString("InsHoldingsAmtofLifeIns", CustomerProfile.getString("InsHoldingsAmtofLifeIns"));
			financialPlanningBO.setString("InsHoldingsPlanCashValue", CustomerProfile.getString("InsHoldingsPlanCashValue"));
			financialPlanningBO.setString("InsHoldingsFixedAnnuities", CustomerProfile.getString("InsHoldingsFixedAnnuities"));
			financialPlanningBO.setString("InsHoldingsIndexAnnuities", CustomerProfile.getString("InsHoldingsIndexAnnuities"));
			financialPlanningBO.setString("InsHoldingsVarAnnuities", CustomerProfile.getString("InsHoldingsVarAnnuities"));
			financialPlanningBO.setString("InsHoldingsImmediateAnnuities", CustomerProfile.getString("InsHoldingsImmediateAnnuities"));
			financialPlanningBO.setString("RiskTolConservative", CustomerProfile.getString("RiskTolConservative"));
			financialPlanningBO.setString("RiskTolModConservative", CustomerProfile.getString("RiskTolModConservative"));
			financialPlanningBO.setString("RiskTolModerate", CustomerProfile.getString("RiskTolModerate"));
			financialPlanningBO.setString("RiskTolModAggressive", CustomerProfile.getString("RiskTolModAggressive"));
			financialPlanningBO.setString("RiskTolAggressive", CustomerProfile.getString("RiskTolAggressive"));
			financialPlanningBO.setString("SellInvestment", CustomerProfile.getString("SellInvestment"));
			financialPlanningBO.setString("FluctuationLot", CustomerProfile.getString("FluctuationLot"));
			financialPlanningBO.setString("FluctuationSome", CustomerProfile.getString("FluctuationSome"));
			financialPlanningBO.setString("FluctuationLittle", CustomerProfile.getString("FluctuationLittle"));
			financialPlanningBO.setString("FluctuationNone", CustomerProfile.getString("FluctuationNone"));
			financialPlanningBO.setString("InvestmentObjPOC", CustomerProfile.getString("InvestmentObjPOC"));
			financialPlanningBO.setString("InvestmentObjIncome", CustomerProfile.getString("InvestmentObjIncome"));
			financialPlanningBO.setString("InvestmentObjModGrowth", CustomerProfile.getString("InvestmentObjModGrowth"));
			financialPlanningBO.setString("InvestmentObjGrowth", CustomerProfile.getString("InvestmentObjGrowth"));
			financialPlanningBO.setString("InvestmentObjAggGrowth", CustomerProfile.getString("InvestmentObjAggGrowth"));
			financialPlanningBO.setString("IncomeTaxBracketFifteen", CustomerProfile.getString("IncomeTaxBracketFifteen"));
			financialPlanningBO.setString("IncomeTaxBracketLessThanThirty", CustomerProfile.getString("IncomeTaxBracketLessThanThirty"));
			financialPlanningBO.setString("IncomeTaxBracketMoreThanThirty", CustomerProfile.getString("IncomeTaxBracketMoreThanThirty"));
			financialPlanningBO.setString("IncomeTaxBracketUnsure", CustomerProfile.getString("IncomeTaxBracketUnsure"));
			financialPlanningBO.setString("AnnInclessthanfifty", CustomerProfile.getString("AnnInclessthanfifty"));
			financialPlanningBO.setString("AnnInclessthanOnefifty", CustomerProfile.getString("AnnInclessthanOnefifty"));
			financialPlanningBO.setString("AnnInclessthanTwofifty", CustomerProfile.getString("AnnInclessthanTwofifty"));
			financialPlanningBO.setString("AnnInclmorethantwofifty", CustomerProfile.getString("AnnInclmorethantwofifty"));
			financialPlanningBO.setString("FinacialNeeds", CustomerProfile.getString("FinacialNeeds"));
			financialPlanningBO.setString("FinacialNeedsUnsure", CustomerProfile.getString("FinacialNeedsUnsure"));
			financialPlanningBO.setString("HouseHoldLessThanFiveHundred", CustomerProfile.getString("HouseHoldLessThanFiveHundred"));
			financialPlanningBO.setString("HouseHoldLessThanOneThousand", CustomerProfile.getString("HouseHoldLessThanOneThousand"));
			financialPlanningBO.setString("HouseHoldMoreThanFiveHuundred", CustomerProfile.getString("HouseHoldMoreThanFiveHuundred"));
			financialPlanningBO.setString("EmploymentAnticipated", CustomerProfile.getString("EmploymentAnticipated"));
			financialPlanningBO.setString("EmploymentAnticipatedUnsure", CustomerProfile.getString("EmploymentAnticipatedUnsure"));
			//financialPlanningBO.setString("PremiumAmount", CustomerProfile.getString("PremiumAmount"));
			//financialPlanningBO.setString("InsuredAmount", CustomerProfile.getString("InsuredAmount"));
			//Customer Client
			//DataObject customerClient = BOHelper.createDataObject(InsuranceConstants.EXTENSIONS_NS, "CustomerClient_Type");
			
	
		if (TXLife_Type_2 == null){
			BOHelper.debug("NO CUSTOMER PROFILE FOUND");
			
			TXLife_Type_2 = BOHelper.createCustomerTXLife();
			DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type_2, true, InsuranceConstants.CUSTOMER_OLIFE_INDEX);
			DataObject partyBO = OLife.createDataObject("Party");
			DataObject customerClient = partyBO.createDataObject("Client", InsuranceConstants.EXTENSIONS_NS, "CustomerClient_Type");
			BOHelper.debug("TXLife_Type_2-----if null");
			BOHelper.debug(TXLife_Type_2);
			
			BOHelper.debug("customerClient");
			BOHelper.debug(customerClient);
			customerClient.set("FinancialPlaning", financialPlanningBO);
			partyBO.set("Client", customerClient);
			BOHelper.debug(partyBO);
			
		}
		else if (TXLife_Type_2 != null) {
			
			DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type_2, true, InsuranceConstants.CUSTOMER_OLIFE_INDEX); 
			
			List partyList = OLife.getList("Party");
			DataObject party = (DataObject) OLife.getList("Party").get(0);
			DataObject customerClient = party.getDataObject("Client");
			BOHelper.debug("*************customerClient******************");
			BOHelper.debug(customerClient);
			String id = null;
			if (customerClient.getDataObject("FinancialPlaning") != null) {
				id =customerClient.getDataObject("FinancialPlaning").getString("ID");
				if (id != null) {
					financialPlanningBO.setString("ID", id);
				}
			}
			customerClient.set("FinancialPlaning", financialPlanningBO);
			party.set("Client", customerClient);
			BOHelper.debug(party);
		}
		
		}
		}catch(Exception e){
			e.printStackTrace();
		}
	}
	
	/**
	 * @param TXLife_Type
	 * @param TXLife_Type_2
	 */
	public static void assignFinancialPlanningToPresentProducts(DataObject TXLife_Type, DataObject TXLife_Type_2) {
		
		DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type_2, true, InsuranceConstants.CUSTOMER_OLIFE_INDEX);
		List OlifeList = new ArrayList();
		OlifeList.add(OLife);
		
		DataObject TXLReq = (DataObject)TXLife_Type.getList(InsuranceConstants.TXLIFE_REQUEST).get(0);
		
		TXLReq.setList(InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX, OlifeList);
	}
	
	/**
	 * @param ProductSelection
	 * @param TXLife_Type_2
	 */
	public static void assignProductSelection(DataObject ProductSelection,DataObject TXLife_Type_2) {
		DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type_2, true, InsuranceConstants.ORDER_OLIFE_INDEX); 
			
		List productList =	OLife.getList("Holding");
		DataObject policyBO = ((DataObject)OLife.getList("Holding").get(0)).getDataObject("Policy");
		BOHelper.debug("*************policyBO***************");
		BOHelper.debug(policyBO);
		
		List productSelectionList = new ArrayList();
		BOHelper.debug("productSelectionList :: "+productSelectionList.toString());
		for (Iterator iterator = productList.iterator(); iterator.hasNext();) {
			DataObject holding = (DataObject) iterator.next();
			DataObject policy = holding.getDataObject("Policy");
			DataObject productInfo = BOHelper.createDataObject("http://www.ibm.com/xmlns/prod/websphere/icp/2010/05/insurance/life/extn/schema/ProductInfo","ProductInfo");
			BOHelper.debug("*************productInfo******************");
			BOHelper.debug(productInfo);
			productInfo.setString("ProductName", policy.getString("PlanName"));
			productInfo.setString("ProductDesc", policy.getString("Description"));
			productInfo.setString("ProductID", policy.getString("ProductCode"));
			productSelectionList.add(productInfo);
		}
		ProductSelection.setList("Product",productSelectionList);
		BOHelper.debug("**************ProductSelection****************");
		BOHelper.debug(ProductSelection);
		BOHelper.debug("**************TXLife_Type_2****************");
		BOHelper.debug(TXLife_Type_2);		
	}
	
	/**
	 * @param TXLife_Type_2
	 * @param ProductSelection
	 * @param productID
	 */
	public static void updateProductSelection(DataObject TXLife_Type_2, DataObject ProductSelection, String productID) {

		try{
		BOHelper.debug(ProductSelection, "in updateProductSelection");
		
		DataObject OLife = BOHelper.getFirstOLifE(TXLife_Type_2, true, InsuranceConstants.ORDER_OLIFE_INDEX);
		
		List holdingList =	OLife.getList("Holding");
		DataObject holdingBO = ((DataObject)OLife.getList("Holding").get(0));
		BOHelper.debug(holdingBO);
		DataObject policyBO = ((DataObject)OLife.getList("Holding").get(0))
			.createDataObject("Policy", BOHelper.EXTENSIONS_NS, "Policy_Type");
		
		BOHelper.debug("*************policyBO***************");
		BOHelper.debug(policyBO);

		List productInfoList = ProductSelection.getList("Product");
		DataObject productInfoSelected = null;
		for (Iterator iterator = productInfoList.iterator(); iterator.hasNext();) {
			DataObject productInfo = (DataObject) iterator.next();
			if (productInfo.getString("SelectedProduct").equalsIgnoreCase("true") ){
				productInfoSelected = productInfo;
				break;
			}
		}
		if (productInfoSelected != null) {
			policyBO.setString("PlanName",productInfoSelected.getString("ProductName"));
			policyBO.setString("ProductCode",productInfoSelected.getString("ProductID"));
			policyBO.setString("Description",productInfoSelected.getString("ProductDesc"));
		}
				
		holdingBO.set("Policy",policyBO);
		BOHelper.debug(holdingBO, "holdingBO~~~~~~~~");
		holdingList.clear();
		holdingList.add(holdingBO);
		BOHelper.debug("productList&&&&&&&&&&&"+holdingList.toString());
		BOHelper.debug(holdingBO);
		BOHelper.debug("*************Only Selected product in the list**********************");
		BOHelper.debug(TXLife_Type_2);
		
		//selected product Id
		productID = productInfoSelected.getString("ProductID");
		}catch(Exception e){
			e.printStackTrace();
		}
	}
		
	/**
	 * @param OrderTXLife_TypeRequest
	 * @param ApplicationInformation
	 * @param TXLife_Type
	 * @param TXLife_Type_2
	 */
	public static void assignToCreateOrder(DataObject OrderTXLife_TypeRequest, DataObject ApplicationInformation, DataObject TXLife_Type, DataObject TXLife_Type_2) {
		BOHelper.debug("inside assignToCreateOrder");
		BOHelper.debug(ApplicationInformation, "assignToCreateOrder::ApplicationInformation is ");
		BOHelper.debug(OrderTXLife_TypeRequest, "assignToCreateOrder::OrderTXLife_TypeRequest is ");
		try{
		
		DataObject person1 = ApplicationInformation.getDataObject("Owner");
		
		DataObject TXLifeReq = BOHelper.createOrderTXLifeRequest(OrderTXLife_TypeRequest);
		DataObject OLife = BOHelper.getFirstOLifE(OrderTXLife_TypeRequest, false, InsuranceConstants.REQUEST_ORDER_OLIFE_INDEX);  
		
		DataObject applicationInformationBO = BOHelper.createDataObject(InsuranceConstants.EXTENSIONS_NS,"ApplicationInformation_Type");
		List<DataObject> appInfoList = new ArrayList<DataObject>();
		appInfoList.add(applicationInformationBO);
		OLife.set("FormInstance", appInfoList);
		
		DataObject ownerBO = applicationInformationBO.createDataObject("Owner");		
		ownerBO.setString("FullName", person1.getString("FirstName"));
		DataObject person = ownerBO.createDataObject("Person");
	
		Calendar cal = Calendar.getInstance();
		cal.setTime(convertStringToDate(person1.getString("DOB")));
		person.setDate("BirthDate", cal.getTime()); 				
		//person.setString("Age", person1.getString("Age"));
		person.createDataObject("Gender").set(0, person1.getString("Gender"));
		BOHelper.debug(person, "person");		
		BOHelper.debug(person1, "person1");
		
		DataObject address = ownerBO.createDataObject("Address", InsuranceConstants.EXTENSIONS_NS, "Address_Type");
		address.setString("ID", person1.getString("AddressID"));
		address.setString("Line1", person1.getString("Address1"));
		address.setString("Line2", person1.getString("Address2"));
		address.setString("City", person1.getString("City"));
		address.setString("State", person1.getString("State"));
		address.setString("Zip", person1.getString("Zip"));
		
		DataObject otherAddress = ownerBO.createDataObject("OtherAddress", InsuranceConstants.EXTENSIONS_NS, "Address_Type");
		otherAddress.setString("Line1", person1.getString("Address1"));
		otherAddress.setString("Line2", person1.getString("Address2"));
		otherAddress.setString("City", person1.getString("City"));
		otherAddress.setString("State", person1.getString("State"));
		otherAddress.setString("Zip", person1.getString("Zip"));

		ownerBO.setString("SSN", person1.getString("SSN"));
		ownerBO.setString("Email", person1.getString("Email"));
		String telephoneType = person1.getString("Age");
		if (telephoneType != null && telephoneType.equals("Home")) {
			ownerBO.setString("HomeTelephone", person1.getString("Sex"));			
		} else { 
			ownerBO.setString("Mobile", person1.getString("Sex"));		
		}
		ownerBO.setString("Citizenship", person1.getString("Citizenship"));
		ownerBO.setString("MaritalStatus", person1.getString("MaritalStatus"));
		ownerBO.setString("SoldLocation", person1.getString("SoldLocation"));
		
		DataObject customer = applicationInformationBO.createDataObject("Customer");
		customer.setString("OwnerType", person1.getString("OwnerType"));

		String isAnnuitantTheOwner = ApplicationInformation.getString("AnnuitantOwner");
		//Annuitant Owner
		applicationInformationBO.setString("isAnnuitantTheOwner", isAnnuitantTheOwner);
		//set to aanutitant
		if (isAnnuitantTheOwner.equals("No")) {
			DataObject person2 = ApplicationInformation.getDataObject("Annuitant");
			DataObject annuitantBO = applicationInformationBO.createDataObject("Annuitant");
			annuitantBO.setString("FullName", person2.getString("FirstName"));
			DataObject annuitantperson = annuitantBO.createDataObject("Person");
			annuitantperson.set("BirthDate", person2.getString("DOB"));
			annuitantperson.set("Age", person2.getString("Age"));
			annuitantperson.createDataObject("Gender").set(0, person2.getString("Gender"));
			BOHelper.debug(annuitantperson);
			BOHelper.debug("Person1");
			BOHelper.debug(person1);
			//DataObject address = ownerBO.createDataObject("Address");
			DataObject annuitantaddress = annuitantBO.createDataObject("Address", InsuranceConstants.EXTENSIONS_NS, "Address_Type");
			annuitantaddress.setString("Line1", person2.getString("Address1"));
			annuitantaddress.setString("Line2", person2.getString("Address2"));
			annuitantaddress.setString("City", person2.getString("City"));
			annuitantaddress.setString("State", person2.getString("State"));
			annuitantaddress.setString("Zip", person2.getString("Zip"));
			
			//DataObject otherAddress = ownerBO.createDataObject("OtherAddress");
			DataObject annuitantotherAddress = annuitantBO.createDataObject("OtherAddress", InsuranceConstants.EXTENSIONS_NS, "Address_Type");
			annuitantotherAddress.setString("Line1", person2.getString("Address1"));
			annuitantotherAddress.setString("Line2", person2.getString("Address2"));
			annuitantotherAddress.setString("City", person2.getString("City"));
			annuitantotherAddress.setString("State", person2.getString("State"));
			annuitantotherAddress.setString("Zip", person2.getString("Zip"));

			annuitantBO.setString("SSN", person2.getString("SSN"));
			annuitantBO.setString("Email", person2.getString("email"));
			annuitantBO.setString("HomeTelephone", person2.getString("HomeTelephone"));
			annuitantBO.setString("Citizenship", person2.getString("Citizenship"));
			annuitantBO.setString("MaritalStatus", person2.getString("MaritalStatus"));
			//annuitantBO.setString("SoldLocation", person2.getString("SoldLocation"));
		}

		DataObject beneficiary = applicationInformationBO.createDataObject("Beneficiary");
		beneficiary.setString("Allocation", ApplicationInformation.getString("BeneficiaryAllocation"));
		beneficiary.setString("Restricted", ApplicationInformation.getString("BeneficiaryRestricted"));
		beneficiary.setString("Irrevocable", ApplicationInformation.getString("BeneficiaryIrrevocable"));
		beneficiary.setString("ContingentBeneficiary", ApplicationInformation.getString("ContingentBeneficiary"));
		
		DataObject beneficiaryDetails = beneficiary.createDataObject("BeneficiaryDetails");
		beneficiaryDetails.setString("FullName", ApplicationInformation.getString("PrimaryName"));
		beneficiaryDetails.setString("SSN", ApplicationInformation.getString("BeneficiarySSN"));
		
		DataObject beneficiaryDetailPerson = beneficiaryDetails.createDataObject("Person");
		beneficiaryDetailPerson.set("BirthDate", ApplicationInformation.getString("BeneficiaryDOB"));			
		beneficiaryDetailPerson.createDataObject("Gender").set(0, ApplicationInformation.getString("BeneficiaryGender"));
		
		DataObject beneficiaryDetailsAddress = beneficiaryDetails.createDataObject("Address");
		beneficiaryDetailsAddress.setString("Line1", ApplicationInformation.getString("BeneficiaryAddress"));

		applicationInformationBO.setString("SourceOfFunds", ApplicationInformation.getString("SourceOfFunds"));
//		applicationInformationBO.setString("ValueOfSourceOfFunds", person1.getString("SourceOfFunds")"ValueOfSourceOfFunds");
		applicationInformationBO.setString("DeathBenefitElection", ApplicationInformation.getString("DeathBenefitElection"));
		applicationInformationBO.setString("IncomeBenefitElection", ApplicationInformation.getString("IncomeBenefitElection"));
		applicationInformationBO.setString("AccumulationBenefitElection", ApplicationInformation.getString("AccumulationBenefitElection"));
		applicationInformationBO.setString("WithdrawalBenefitElection", ApplicationInformation.getString("WithdrawalBenefitElection"));

		DataObject investmentSelection1 = applicationInformationBO.createDataObject("InvestmentSelection");
		DataObject investmentSelection2 = applicationInformationBO.createDataObject("InvestmentSelection");
		DataObject investmentSelection3 = applicationInformationBO.createDataObject("InvestmentSelection");
		DataObject investmentSelection4 = applicationInformationBO.createDataObject("InvestmentSelection");
		investmentSelection1.setString("Detail",ApplicationInformation.getString("InvestmentElectionDetail1"));
		investmentSelection2.setString("Detail",ApplicationInformation.getString("InvestmentElectionDetail2"));
		investmentSelection3.setString("Detail",ApplicationInformation.getString("InvestmentElectionDetail3"));
		investmentSelection4.setString("Detail",ApplicationInformation.getString("InvestmentElectionDetail4"));
		investmentSelection1.setString("Percentage",ApplicationInformation.getString("InvestmentElectionPer1"));
		investmentSelection2.setString("Percentage",ApplicationInformation.getString("InvestmentElectionPer2"));
		investmentSelection3.setString("Percentage",ApplicationInformation.getString("InvestmentElectionPer3"));
		investmentSelection4.setString("Percentage",ApplicationInformation.getString("InvestmentElectionPer4"));
		
		DataObject dca = applicationInformationBO.createDataObject("DCA");
		dca.setString("DollarcostAvg", ApplicationInformation.getString("DollarcostAvg"));
		dca.setString("AssetAllocation",ApplicationInformation.getString("AssetAllocation"));
		dca.setString("InterestSweep", ApplicationInformation.getString("InterestSweep"));
		
		dca.setString("TransferDollarCost", ApplicationInformation.getString("TransferDollarCost"));
		dca.setString("TransferDollarCostValue", ApplicationInformation.getString("TransferDollarCostValue"));
		dca.setString("TransferDollarCostAccount", ApplicationInformation.getString("TransferDollarCostAccount"));
		
		DataObject dollarCostAvgProgram1 = dca.createDataObject("DollarCostAvgProgram");
		DataObject dollarCostAvgProgram2 = dca.createDataObject("DollarCostAvgProgram");
		DataObject dollarCostAvgProgram3 = dca.createDataObject("DollarCostAvgProgram");
		DataObject dollarCostAvgProgram4 = dca.createDataObject("DollarCostAvgProgram");
		
		dollarCostAvgProgram1.setString("Detail", ApplicationInformation.getString("DollarCostAvgDetail1"));
		dollarCostAvgProgram1.setString("Percentage", ApplicationInformation.getString("DollarCostAvgPer1"));
		dollarCostAvgProgram2.setString("Detail", ApplicationInformation.getString("DollarCostAvgDetail2"));
		dollarCostAvgProgram2.setString("Percentage", ApplicationInformation.getString("DollarCostAvgPer2"));
		dollarCostAvgProgram3.setString("Detail", ApplicationInformation.getString("DollarCostAvgDetail3"));
		dollarCostAvgProgram3.setString("Percentage", ApplicationInformation.getString("DollarCostAvgPer3"));
		dollarCostAvgProgram4.setString("Detail", ApplicationInformation.getString("DollarCostAvgDetail4"));
		dollarCostAvgProgram4.setString("Percentage", ApplicationInformation.getString("DollarCostAvgPer4"));
		
		dca.setString("DCAPeriod", ApplicationInformation.getString("DCA"));
		//dca.set("DCAStartDate", person1.getString("")); date+month
		dca.set("DCAEndDate", ApplicationInformation.getString("DCAEnd"));
		applicationInformationBO.set("Owner",ownerBO);
		
		
		List oLifeList = new ArrayList();		
		oLifeList.add(SDOTransformationUtils.cloneDataObject(OLife));		
		TXLife_Type_2.createDataObject(InsuranceConstants.TXLIFE_RESPONSE)
			.setList(InsuranceConstants.ORDER_OLIFE_INDEX, oLifeList);

		}catch(Exception e){
			BOHelper.debug("inside exception--------");
			e.printStackTrace();
		}
		BOHelper.debug("******FINAL OrderTXLife_TypeRequest***********");
		BOHelper.debug(TXLife_Type_2, "TXLife_Type_2");
		BOHelper.debug(OrderTXLife_TypeRequest, "OrderTXLife_TypeRequest - final");		
	}

	/**
	 * Convert String to Date.
	 * 
	 * @param string
	 * @return
	 */
	private static Date convertStringToDate(String string) {
		SimpleDateFormat sdf = new SimpleDateFormat("MM/dd/yyyy");
		Date date = null;
		try {
			date = sdf.parse(string);
		} catch (ParseException e) {
			e.printStackTrace();
		} 
		return date;
	}

	/**
	 * @param txLife
	 * @param appInfo
	 */
	public static void prepopulateFormData(DataObject txLife, DataObject appInfo) {
		try {
			DataObject OLife = BOHelper.getFirstOLifE(txLife, false, InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX);
			if (OLife.getList("Party") != null && 
					OLife.getList("Party").size()>0) {
				DataObject party = (DataObject)OLife.getList("Party").get(0);
				DataObject person = party.getDataObject("Person");			
				DataObject address = (DataObject)party.getList("Address").get(0);			
				DataObject appOwner = appInfo.createDataObject("Owner");
				if (person != null) {
					appOwner.setString("FirstName", person.getString("FirstName") + 
							" " + person.getString("LastName"));		
					SimpleDateFormat sdf = new SimpleDateFormat("MM/dd/yyyy");
					appOwner.setString("DOB", sdf.format(person.getDate("BirthDate")));
					if (person.getDataObject("Gender") != null ) {
						appOwner.setString("Gender", (String)person.getDataObject("Gender").get(0));
					}
				}
				
				if (address != null) {					
					appOwner.setString("AddressID", address.getString("ID"));
					appOwner.setString("Address1", address.getString("Line1"));
					appOwner.setString("Address2", address.getString("Line2"));
					appOwner.setString("City", address.getString("City"));
					appOwner.setString("State", address.getString("State"));
					appOwner.setString("Zip", address.getString("Zip"));
				}
				appOwner.setString("HomeTelephone", ((DataObject)party.getList("Phone").get(1)).getString("DialNumber"));
				appOwner.setString("Mobile", ((DataObject)party.getList("Phone").get(0)).getString("DialNumber"));
				appOwner.setString("SSN", party.getString("SSN"));
				appOwner.setString("Citizenship", party.getString("Citizenship"));
				
				if (party.getDataObject("EMailAddress") != null) {
					appOwner.setString("Email", party.getDataObject("EMailAddress").getString("AddrLine"));
				}
				appOwner.setString("MaritalStatus", person.getDataObject("MarStat").getString(0));				
				if (party.getDataObject("Client") != null) {
					appOwner.setString("CustomerId", party.getDataObject("Client").getString("CustomerID"));				
				}
				
			}
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}
	/**
	 * @param SuitabilityReviewPrincipalApproval
	 * @param txLife
	 */
	public static void assignToSuitabilityReviewPrincipalApproval(DataObject SuitabilityReviewPrincipalApproval, DataObject txLife) {
		try{			
		
		DataObject OLife = BOHelper.getFirstOLifE(txLife, false, InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX);
		
		List partyList = OLife.getList("Party");
		DataObject party = (DataObject) OLife.getList("Party").get(0);
		DataObject person = party.getDataObject("Person");		
		DataObject clientInfoBO = SuitabilityReviewPrincipalApproval.createDataObject("ClientInfo");
		clientInfoBO.setString("FirstName", person.getString("FirstName")+" "+person.getString("LastName"));
		BOHelper.debug(clientInfoBO);
		}catch(Exception e){
			e.printStackTrace();			
		}
	}
	
}
