/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.insurance.life.reference.mock.impl;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.lang.StringUtils;

import com.ibm.websphere.icp.industry.db.entities.BaseObject;
import com.ibm.websphere.icp.industry.db.manager.IWicpDBManager;
import com.ibm.websphere.icp.insurance.life.db.entities.Address;
import com.ibm.websphere.icp.insurance.life.db.entities.Applicationinformation;
import com.ibm.websphere.icp.insurance.life.db.entities.Benificiary;
import com.ibm.websphere.icp.insurance.life.db.entities.Customer;
import com.ibm.websphere.icp.insurance.life.db.entities.Dca;
import com.ibm.websphere.icp.insurance.life.db.entities.Esignconsent;
import com.ibm.websphere.icp.insurance.life.db.entities.Financialplanning;
import com.ibm.websphere.icp.insurance.life.db.entities.Percentagedetails;
import com.ibm.websphere.icp.insurance.life.db.entities.Person;
import com.ibm.websphere.icp.insurance.life.db.entities.Product;
import com.ibm.websphere.icp.insurance.life.db.manager.DBManager;
import com.ibm.websphere.icp.insurance.life.reference.util.BOHelper;
import com.ibm.websphere.icp.insurance.life.reference.util.InsuranceConstants;
import commonj.sdo.DataObject;

public class ServiceImplementations implements ServiceInterfaces {

	/* (non-Javadoc)
	 * @see com.ibm.websphere.icp.insurance.life.reference.mock.impl.ServiceInterfaces#CreateOrder(commonj.sdo.DataObject)
	 */
	@Override
	public DataObject CreateOrder(DataObject txlife) {
		BOHelper.debug("*******CREATE ORDER*****");
		DataObject createOrderResponse = BOHelper.createOrderTXLife();
	
		BOHelper.debug(txlife, "---------------start Create Order");
		try{
				
			DataObject olife = BOHelper.getFirstOLifE(txlife, false, InsuranceConstants.REQUEST_ORDER_OLIFE_INDEX); 
			
		DataObject formInst = (DataObject)olife.getList("FormInstance").get(0);
		
		DataObject customerDO = formInst.getDataObject("Customer");		
		Customer customer = new Customer();
		customer.setOwnertype(customerDO.getString("OwnerType"));
		
		Applicationinformation appInfo = new Applicationinformation();
		appInfo.setContracttype(formInst.getString("ContractType"));
		appInfo.setPlantype(formInst.getString("PlanType"));

		Set<Applicationinformation> set = new HashSet<Applicationinformation>();
		set.add(appInfo);
		customer.setApplicationinformationCollection(set);		
		IWicpDBManager wicpDBManager = DBManager.getWicpDBManager();
		
		Set<Person> ownerPersonList = new HashSet<Person>();
		DataObject ownerDO = formInst.getDataObject("Owner");
		Person ownerPerson = null;
		int custId = 0;
		if (ownerDO != null) {
			ownerPerson = createPersonEntity(ownerDO);
			ownerPersonList.add(ownerPerson);
			custId = ownerPerson.getId();			
		}
		customer.setPersonCollection(ownerPersonList);
		customer.setId(custId);		
		
		String isAnnuitantTheOwner = formInst.getString("isAnnuitantTheOwner");
		appInfo.setIsannuitanttheowner(isAnnuitantTheOwner);

		appInfo.setSourceoffunds(formInst.getString("SourceOfFunds"));
		appInfo.setValueofsourceoffunds(formInst.getString("ValueOfSourceOfFunds"));
		appInfo.setDeathbenefitelection(formInst.getString("DeathBenefitElection"));
		appInfo.setIncomebenefitelection(formInst.getString("IncomeBenefitElection"));
		appInfo.setAccumulationbenefitelection(formInst.getString("AccumulationBenefitElection"));
		appInfo.setWithdrawalbenefitelection(formInst.getString("WithdrawalBenefitElection"));

		Set<Percentagedetails> investmentSelectionCollection = new HashSet<Percentagedetails>();
		for (int i = 0; i < 4; i++) {
			DataObject investmentSelectionDO = formInst.createDataObject("InvestmentSelection");
			if (investmentSelectionDO != null) {
				Percentagedetails pd = new Percentagedetails();
				pd.setDetail(investmentSelectionDO.getString("Detail"));
				pd.setPercentage(investmentSelectionDO.getString("Percentage"));			
				investmentSelectionCollection.add(pd);
			}
		}
		if (investmentSelectionCollection.size()>0) {
			appInfo.setPercentagedetailsCollection(investmentSelectionCollection);
		}
		
		DataObject dcaDO = formInst.getDataObject("DCA");

		Dca dca = new Dca();
		
		Set<Dca> dcaCollection = new HashSet<Dca>();
		dcaCollection.add(dca);
		appInfo.setDcaCollection(dcaCollection);

		dca.setDollarcostavg(dcaDO.getString("DollarcostAvg"));
		dca.setAssetallocation(dcaDO.getString("AssetAllocation"));
		dca.setInterestsweep(dcaDO.getString("InterestSweep"));
		dca.setTransferdollarcost(dcaDO.getString("TransferDollarCost"));
		dca.setTransferdollarcostvalue(dcaDO.getString("TransferDollarCostValue"));
		dca.setTransferdollarcostaccount(dcaDO.getString("TransferDollarCostAccount"));
				
		Set<Percentagedetails> dollarCostAvgProgramCollection = new HashSet<Percentagedetails>();
		for (int i = 0; i < 4; i++) {
			DataObject dollarCostAvgProgramDO = (DataObject)dcaDO.getList("DollarCostAvgProgram").get(0);
			if (dollarCostAvgProgramDO != null) {
				Percentagedetails pd = new Percentagedetails();
				pd.setDetail(dollarCostAvgProgramDO.getString("Detail"));
				pd.setPercentage(dollarCostAvgProgramDO.getString("Percentage"));			
				dollarCostAvgProgramCollection.add(pd);
			}
		}
		if (dollarCostAvgProgramCollection.size()>0) {
			dca.setPercentagedetailsCollection(dollarCostAvgProgramCollection);
		}
		dca.setDcaperiod(dcaDO.getString("DCAPeriod"));
		if (dcaDO.getDate("DCAStartDate") != null) {
			dca.setDcastartdate(new java.sql.Date(dcaDO.getDate("DCAStartDate").getTime()));
		}
		if (dcaDO.getDate("DCAEndDate") != null) {
			dca.setDcaenddate(new java.sql.Date(dcaDO.getDate("DCAEndDate").getTime()));
		}

		saveBenificiaryDetails((Applicationinformation)customer
				.getApplicationinformationCollection().iterator().next(), formInst);
		
		wicpDBManager.update(customer);	
		
		BOHelper.debug("---------------end Create Order");
		
		BOHelper.debug("customer.getId(:::::"+customer.getId());
		BOHelper.debug("appInfo.getId(:::::"+ customer.getApplicationinformationCollection().iterator().next().getId());
		
//		if (ownerPerson != null) {
//			ownerPerson.setCustomer(customer);
//			wicpDBManager.update(ownerPerson);			
//		}
		
		BOHelper.debug("---------------ownere data updated");
		
		int appId = ((Applicationinformation)customer
				.getApplicationinformationCollection().iterator().next()).getId();
		
//		Benificiary benificiary = saveBenificiaryDetails((Applicationinformation)customer
//				.getApplicationinformationCollection().iterator().next(), formInst, wicpDBManager);
		
		
		DataObject olifeFromRequest = BOHelper.getFirstOLifE(createOrderResponse, true, InsuranceConstants.ORDER_OLIFE_INDEX);
		DataObject reponseFormInst = olifeFromRequest.createDataObject("FormInstance");
		reponseFormInst.setString("FormInstanceTrackingID", String.valueOf(appId));		
		
		}catch(Exception e){
			e.printStackTrace();
		}
		return createOrderResponse;
	}

	/**
	 * Persist BenificiaryDetails.
	 * 
	 * @param appInfo
	 * @param formInst
	 * @return {@link Benificiary}
	 */
	private Benificiary saveBenificiaryDetails(Applicationinformation appInfo, DataObject formInst) {
		BOHelper.debug("saveBenificiaryDetails");
		DataObject beneficiaryDO = formInst.getDataObject("Beneficiary");
		Benificiary benificiary = new Benificiary();
		Set<Benificiary> benificiaryCollection = new HashSet<Benificiary>();
		
		benificiary.setAllocation(beneficiaryDO.getString("Allocation"));
		benificiary.setRestricted(beneficiaryDO.getString("Restricted"));
		benificiary.setIrrevocable(beneficiaryDO.getString("Irrevocable"));
		benificiary.setContingentbeneficiary(beneficiaryDO.getString("ContingentBeneficiary"));
		//benificiary.setApplicationinformation(appInfo);
		
		Set<Person> benificiaryPersonCollection = new HashSet<Person>();	
		
		benificiaryPersonCollection.add(saveBeneficiaryPerson(beneficiaryDO));
		
		benificiary.setPersonCollection(benificiaryPersonCollection);

		benificiaryCollection.add(benificiary);
		appInfo.setBenificiaryCollection(benificiaryCollection);
		
		//wicpDBManager.save(benificiary);
		//BOHelper.debug("benificiary:"+benificiary.getId());
		return benificiary;
	}

	/**
	 * Persist Person details for beneficiary.
	 *  
	 * @param beneficiaryDO
	 * @param wicpDBManager 
	 * @return {@link Person}
	 */
	private Person saveBeneficiaryPerson(DataObject beneficiaryDO) {
		BOHelper.debug("saveBeneficiaryPerson");
		Person benificiaryPerson = new Person();

		DataObject beneficiaryDetailsDO = beneficiaryDO.getDataObject("BeneficiaryDetails");
		
		String fullname = beneficiaryDetailsDO.getString("FullName");
		if (fullname !=null && !"".equals(fullname)) {
			String firstname = null;
			if (fullname.indexOf(" ") > 0) {
				firstname = fullname.substring(0, fullname.indexOf(" "));
			} else {
				firstname = fullname;
			}
			String lastname = null;
			if (fullname.trim().indexOf(" ") > 0) {
				lastname = fullname.substring(fullname.indexOf(" ")+1, fullname.length());
			}
			benificiaryPerson.setFirstname(firstname);
			benificiaryPerson.setLastname(lastname);
		}

		benificiaryPerson.setSsn(beneficiaryDetailsDO.getString("SSN"));
		
		DataObject beneficiaryDetailPersonDO = beneficiaryDetailsDO.getDataObject("Person");
		if (beneficiaryDetailPersonDO.getDate("BirthDate") != null) {
			benificiaryPerson.setDob(new java.sql.Date(beneficiaryDetailPersonDO.getDate("BirthDate").getTime()));
		}
		if (beneficiaryDetailPersonDO.createDataObject("Gender") != null) {
			benificiaryPerson.setGender((String)beneficiaryDetailPersonDO.createDataObject("Gender").get(0));
		}
		
		DataObject beneficiaryDetailsAddressDO = beneficiaryDetailsDO.getDataObject("Address");
		if (beneficiaryDetailsAddressDO != null) {
			Address benificiaryPersonAddress = new Address();
			benificiaryPersonAddress.setAddress1(beneficiaryDetailsAddressDO.getString("Line1"));
			benificiaryPerson.setAddress(benificiaryPersonAddress);
		}		
		
		//wicpDBManager.save(benificiaryPerson);
		//BOHelper.debug("benificiaryPerson:"+benificiaryPerson.getId());
		//BOHelper.debug("benificiaryPerson.getAddress:"+benificiaryPerson.getAddress().getId());
		return benificiaryPerson;
	}

	/**
	 * Populate the Person Entity with data from Person DataObject.
	 * 
	 * @param ownerDO
	 * @param Id 
	 * @return {@link Person}
	 */
	public Person createPersonEntity(DataObject ownerDO) {
		Person owner = new Person();

		String fullname = ownerDO.getString("FullName");
		/*if (fullname !=null && !"".equals(fullname)) {
			String firstname = null;
			if (fullname.indexOf(" ") > 0) {
				firstname = fullname.substring(0, fullname.indexOf(" "));
			} else {
				firstname = fullname;
			}
			String lastname = null;
			if (fullname.trim().indexOf(" ") > 0) {
				lastname = fullname.substring(fullname.indexOf(" ")+1, fullname.length());
			}
			owner.setFirstname(firstname);
			owner.setLastname(lastname);
		}*/
		DataObject person = ownerDO.getDataObject("Person");
		if (person!=null) {
			if (person.getDate("BirthDate") != null) {
				owner.setDob(new java.sql.Date(person.getDate("BirthDate").getTime()));
			}
			//owner.setAge(person.getInt("Age"));
			if (person.createDataObject("Gender") != null) {
				owner.setGender((String)person.createDataObject("Gender").get(0));
			}
		}
		//owner.setSsn(ownerDO.getString("SSN"));
		owner.setEmail(ownerDO.getString("Email"));
			
		owner.setHometelephone(ownerDO.getString("HomeTelephone"));
		owner.setMobile(ownerDO.getString("Mobile"));
		
		BOHelper.debug("ownerDO.getString(HomeTelephone)-"+ownerDO.getString("HomeTelephone"));
		BOHelper.debug("owner.setHometelephone-"+owner.getHometelephone());
		owner.setCitizenship(ownerDO.getString("Citizenship"));
		owner.setMaritalstatus(ownerDO.getString("MaritalStatus"));
		owner.setSoldlocation(ownerDO.getString("SoldLocation"));
		
		DataObject addressDO = ownerDO.getDataObject("Address");
		if (addressDO != null) {
			Address address = new Address();
			owner.setAddress(address);
			BOHelper.debug("address.getId - "+address.getId());
			address.setAddress1(addressDO.getString("Line1"));
			address.setAddress2(addressDO.getString("Line2"));
			address.setCity(addressDO.getString("City"));
			address.setState(addressDO.getString("State"));
			address.setZip(addressDO.getString("Zip"));
			
			if (addressDO.getString("ID") != null) {
				int Id = Integer.parseInt(addressDO.getString("ID"));
				address.setId(Id); // this should update the address
				owner.setId(Id);				
				//wicpDBManager.update(address);				
			}
		}		
		addressDO = ownerDO.getDataObject("OtherAddress");
		if (addressDO != null) {
			Address otheraddress = new Address();
			//owner.setOtheraddress(otheraddress);
			otheraddress.setAddress1(addressDO.getString("Line1"));
			otheraddress.setAddress2(addressDO.getString("Line2"));
			otheraddress.setCity(addressDO.getString("City"));
			otheraddress.setState(addressDO.getString("State"));
			otheraddress.setZip(addressDO.getString("Zip"));
		}
		
		//wicpDBManager.update(owner);
		BOHelper.debug("owner for order created."+owner.toString());
		return owner;
	}

	/* (non-Javadoc)
	 * @see com.ibm.websphere.icp.insurance.life.reference.mock.impl.ServiceInterfaces#GenerateSuitabilityDocumentation(commonj.sdo.DataObject)
	 */
	@Override
	public DataObject GenerateSuitabilityDocumentation(DataObject document) {
		BOHelper.debug("in GenerateSuitabilityDocumentation - mock implementation - does nothing");			 
		return createTXLifeByNS(true, null, 0);
	}

	/* (non-Javadoc)
	 * @see com.ibm.websphere.icp.insurance.life.reference.mock.impl.ServiceInterfaces#RecordESignature(commonj.sdo.DataObject)
	 */
	@Override
	public DataObject RecordESignature(DataObject eSignatureRequest) {
		BOHelper.debug("in RecordESignature");
		DataObject olifeFromRequest = BOHelper.getFirstOLifE(eSignatureRequest, false, InsuranceConstants.ORDER_OLIFE_INDEX);
		if (olifeFromRequest.getList("FormInstance") != null && olifeFromRequest.getList("FormInstance").size()>0) {
			DataObject formInst = (DataObject)olifeFromRequest.getList("FormInstance").get(0);
			String appId = formInst.getString("FormInstanceTrackingID");
			BOHelper.debug("appId:"+appId);
			if (appId != null) {
				Map<String, Object> map = new HashMap<String, Object>();
				Applicationinformation applicationinformation = new Applicationinformation();
				applicationinformation.setId(new Integer(appId));
				//create ESignatureAcceptance
				Esignconsent esignconsent = new Esignconsent();
				esignconsent.setAccept("1");
				esignconsent.setApplicationinformation(applicationinformation);
				
				DBManager.getWicpDBManager().save(esignconsent);
				BOHelper.debug("esignconsent:"+esignconsent.getId());
			}
		}		
		BOHelper.debug("eSignature persisted succeessfully");
		
		DataObject eSignResponse = createTXLifeByNS(true, null, 0);
		((DataObject)eSignResponse.getList(InsuranceConstants.TXLIFE_RESPONSE)
				.get(0))
				.createDataObject("TransResult")
				.createDataObject("ResultInfo")
				.setString("ResultInfoDesc", "eSignature recored successfully");
		
		return eSignResponse;

	}

	/* (non-Javadoc)
	 * @see com.ibm.websphere.icp.insurance.life.reference.mock.impl.ServiceInterfaces#RetrieveCustomerDetails(commonj.sdo.DataObject)
	 */
	@Override
	public DataObject RetrieveCustomerDetails(DataObject retrieveCustomerDetailsRequest) {
		return findCustomerBySearchCriteria(retrieveCustomerDetailsRequest);
	}

	/* (non-Javadoc)
	 * @see com.ibm.websphere.icp.insurance.life.reference.mock.impl.ServiceInterfaces#RetrieveCustomerProfile(commonj.sdo.DataObject)
	 */
	@Override
	public DataObject RetrieveCustomerProfile(DataObject retrieveCustomerProfile) {
		BOHelper.debug("inside RetrieveCustomerProfile Mock Service");
		DataObject retrieveCustomerProfileResponse = null;
		String customerId = ((DataObject)((DataObject)((DataObject)retrieveCustomerProfile
							.getList(InsuranceConstants.TXLIFE_REQUEST).get(0))
							.getList(InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX).get(0))
							.getList("Party").get(0))
							.getDataObject("Client")
							.getString("CustomerID");
		
		DataObject client = ((DataObject)((DataObject)((DataObject)retrieveCustomerProfile
				.getList(InsuranceConstants.TXLIFE_REQUEST).get(0))
				.getList(InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX).get(0))
				.getList("Party").get(0))
				.getDataObject("Client");

			BOHelper.debug(client, "%%%%%%client%%%%%%%%%");			
		
		DataObject party= (DataObject) ((DataObject)((DataObject)retrieveCustomerProfile
				.getList(InsuranceConstants.TXLIFE_REQUEST).get(0))
				.getList(InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX).get(0))
				.getList("Party").get(0);
		
			BOHelper.debug(party, "%%%%%%party%%%%%%%%%");			
		
		DataObject personDO = party.getDataObject("Person");
		BOHelper.debug("customerId:"+customerId);	
		List  addressDOList =  party.getList("Address");
		DataObject addressDO = (DataObject) addressDOList.get(0);

		if (customerId != null) { 
			BOHelper.debug("customerId---1:"+customerId);
			
			Map<String, Object> map = new HashMap<String, Object>();			
			
			map.put("customer_id", new Integer(customerId));
			List boList = DBManager.getWicpDBManager().executeNamedQuery("getFinancialplanningByCustomerId", map);
			if (boList.iterator().hasNext()) {
				Financialplanning financialplanning = (Financialplanning)boList.iterator().next();
				retrieveCustomerProfileResponse = createCustomerProfileObject(financialplanning, customerId, addressDO, personDO, true);
			}	
			else{
				BOHelper.debug("NO Customer Profile Found");
			}
		}
		return retrieveCustomerProfileResponse;
	}

	/**
	 * Create TXLife by namespace - for request or response.
	 * 
	 * @param byResponseNS
	 * @param oLifeNS
	 * @return {@link DataObject}
	 */
	private DataObject createTXLifeByNS(boolean byResponseNS, String oLifeNS, int olifeIndex) {
		DataObject txLife = null;
		DataObject txLifeR = null;
		if (byResponseNS) {
			txLife = BOHelper.createDataObject(InsuranceConstants.TXLIFE_RESPONSE_NS, InsuranceConstants.TXLIFE_TYPE);
			txLifeR = txLife.createDataObject(InsuranceConstants.TXLIFE_RESPONSE);			
		} else {
			txLife = BOHelper.createDataObject(InsuranceConstants.TXLIFE_REQUEST_NS, InsuranceConstants.TXLIFE_TYPE);
			txLifeR = txLife.createDataObject(InsuranceConstants.TXLIFE_REQUEST);			
		}
		if (txLifeR != null && oLifeNS != null) {
			//txLifeR.createDataObject(InsuranceConstants.OLIFE, oLifeNS, InsuranceConstants.OLIFE_TYPE);
			DataObject oLife = BOHelper.createDataObject(oLifeNS, InsuranceConstants.OLIFE_TYPE);			
			List oLifeList = new ArrayList();
			oLifeList.add(oLife);
			txLifeR.setList(olifeIndex, oLifeList);	

		}
		return txLife;		
	}

	/**
	 * Return the first instrance of OLifE with in the given TXLife object.
	 * 
	 * @param txLife
	 * @param byResponseNS
	 * @return {@link DataObject}
	 */
/*	private DataObject getFirstOLifE(DataObject txLife, boolean byResponseNS) {
		if (byResponseNS) {
			return (DataObject) ((DataObject) txLife.getList(InsuranceConstants.TXLIFE_RESPONSE).get(0))
			.getList(InsuranceConstants.OLIFE).get(0);
		} else {
			return (DataObject) ((DataObject) txLife.getList(InsuranceConstants.TXLIFE_REQUEST).get(0))
			.getList(InsuranceConstants.OLIFE).get(0);
		}
	}
*/
	/**
	 * Create CustomerProfile Object.
	 * 
	 * @param fPlanEntity {@link Financialplanning}
	 * @param customerId {@link String}
	 * @param addressDO2 {@link DataObject}
	 * @param personDO2 {@link DataObject}
	 * @param createResponseObject boolean
	 * @return {@link DataObject}
	 */
	private DataObject createCustomerProfileObject(Financialplanning fPlanEntity, String customerId, DataObject addressDO2, DataObject personDO2, boolean createResponseObject) {
		
		DataObject txLife = createTXLifeByNS(createResponseObject, null, 0);		
		DataObject txLifeR = (DataObject)txLife.getList(InsuranceConstants.TXLIFE_RESPONSE).get(0);
		DataObject olife = BOHelper.createDataObject(InsuranceConstants.ORDER_OLIFE_NS, "OLifE_Type") ;
		List oLifeList = new ArrayList();
		oLifeList.add(olife);
		txLifeR.setList(InsuranceConstants.ORDER_OLIFE_INDEX, oLifeList);	

		DataObject customerParty = BOHelper.createDataObject(InsuranceConstants.EXTENSIONS_NS, "OrderParty_Type");		
		List<DataObject> partList = new ArrayList<DataObject>();
		partList.add(customerParty);
		DataObject state = (DataObject) addressDO2.get(0);		
		String state1 = (String) addressDO2.get(0);		
		
		DataObject personDO = customerParty.createDataObject("Person");
		personDO.setString("FirstName", personDO2.getString("FirstName"));
		DataObject addressDO = customerParty.createDataObject("Address");
		
		DataObject addressStateDO = BOHelper.boFactory.create(BOHelper.CUSTOMER_OLIFE_NS, "AddressStateTC_Type");
		addressStateDO.set(0, state);
		addressDO.set("AddressStateTC", addressStateDO);
		
		olife.setList("Party", partList);
		
		DataObject customerClient = BOHelper.createDataObject(InsuranceConstants.EXTENSIONS_NS, "CustomerClient_Type");		
		customerParty.set("Client", customerClient);
		
		customerClient.setString("CustomerID", customerId);

		BOHelper.debug("fPlanEntity:"+fPlanEntity);
		if (fPlanEntity != null) {			
			
			DataObject fPlanning = customerClient.createDataObject("FinancialPlaning");
			
			BOHelper.debug("fPlanEntity.getId-----------:"+String.valueOf(fPlanEntity.getId()));
			fPlanning.setString("ID", String.valueOf(fPlanEntity.getId()));
			fPlanning.setString("PrimaryRetirementIncome", fPlanEntity.getPrimaryretirementincome());
			fPlanning.setString("SupplementalIncomeRetirement", fPlanEntity.getSupplementalincomeretirement());
			fPlanning.setString("AssetAccumulation", fPlanEntity.getAssetaccumulation());
			fPlanning.setString("AccumulationForWealthTransfer", fPlanEntity.getAccumulationforwealthtransfer());
			fPlanning.setString("DeathBenefit", fPlanEntity.getDeathbenefit());
			fPlanning.setString("EnhancedDeathBenefit", fPlanEntity.getEnhanceddeathbenefit());
			fPlanning.setString("SystematicWithdrawalBenifit", fPlanEntity.getSystematicwithdrawalbenifit());
			fPlanning.setString("GuaranteedAccumulationBenefit", fPlanEntity.getGuaranteedaccumulationbenefit());
			fPlanning.setString("GuaranteedIncomeRider", fPlanEntity.getGuaranteedincomerider());
			fPlanning.setString("TimeLestshanThreeYears", fPlanEntity.getTimelestshanthreeyears());
			fPlanning.setString("TimeThreeToFiveYears", fPlanEntity.getTimethreetofiveyears());
			fPlanning.setString("TimeFiveToTenYears", fPlanEntity.getTimefivetotenyears());
			fPlanning.setString("TimeTenYears", fPlanEntity.getTimetenyears());
			fPlanning.setString("LifeTime", fPlanEntity.getLifetime());
			fPlanning.setString("InvestmentExpNone", fPlanEntity.getInvestmentexpnone());
			fPlanning.setString("InvestmentExpLimited", fPlanEntity.getInvestmentexplimited());
			fPlanning.setString("InvestmentExpExperienced", fPlanEntity.getInvestmentexpexperienced());
			fPlanning.setString("InvestmentExpExtensive", fPlanEntity.getInvestmentexpextensive());
			fPlanning.setString("InvestLessThan25", fPlanEntity.getInvestlessthan25());
			fPlanning.setString("InvestLessThan75", fPlanEntity.getInvestlessthan75());
			fPlanning.setString("InvestLessThanOneLakh", fPlanEntity.getInvestlessthanonelakh());
			fPlanning.setString("InvestMoreThanOneLakh", fPlanEntity.getInvestmorethanonelakh());
			fPlanning.setString("QualifiedPuchase", fPlanEntity.getQualifiedpuchase());
			fPlanning.setString("QualifiedNonPuchase", fPlanEntity.getQualifiednonpuchase());
			fPlanning.setString("AddRegularBasis", fPlanEntity.getAddregularbasis());
			fPlanning.setString("AddirRegularBasis", fPlanEntity.getAddirregularbasis());
			fPlanning.setString("FundInvestmentExpNone", fPlanEntity.getFundinvestmentexpnone());
			fPlanning.setString("InvestmentExpBonds", fPlanEntity.getInvestmentexpbonds());
			fPlanning.setString("InvestmentExpFutures", fPlanEntity.getInvestmentexpfutures());
			fPlanning.setString("InvestmentExpMutualFunds", fPlanEntity.getInvestmentexpmutualfunds());
			fPlanning.setString("InvestmentExpAnnunities", fPlanEntity.getInvestmentexpannunities());
			fPlanning.setString("InvestmentExpCDs", fPlanEntity.getInvestmentexpcds());
			fPlanning.setString("InvestmentExpEquities", fPlanEntity.getInvestmentexpequities());
			fPlanning.setString("InvestmentExpOptions", fPlanEntity.getInvestmentexpoptions());
			fPlanning.setString("InvestmentExpIndexedAnnunities", fPlanEntity.getInvestmentexpindexedannunities());
			fPlanning.setString("InvestmentExpFixedAnnunities", fPlanEntity.getInvestmentexpfixedannunities());
			fPlanning.setString("InvestmentExpVarLifeIns", fPlanEntity.getInvestmentexpvarlifeins());
			fPlanning.setString("SponsoredEmployerPrg", fPlanEntity.getSponsoredemployerprg());
			fPlanning.setString("NonSponsoredEmployerPrg", fPlanEntity.getNonsponsoredemployerprg());
			fPlanning.setString("MaxQualifiedPlan", fPlanEntity.getMaxqualifiedplan());
			fPlanning.setString("MinQualifiedPlan", fPlanEntity.getMinqualifiedplan());
			fPlanning.setString("NoQualifiedPlan", fPlanEntity.getNoqualifiedplan());
			fPlanning.setString("InsHoldingsAmtofLifeIns", fPlanEntity.getInsholdingsamtoflifeins());
			fPlanning.setString("InsHoldingsPlanCashValue", fPlanEntity.getInsholdingsplancashvalue());
			fPlanning.setString("InsHoldingsFixedAnnuities", fPlanEntity.getInsholdingsfixedannuities());
			fPlanning.setString("InsHoldingsIndexAnnuities", fPlanEntity.getInsholdingsindexannuities());
			fPlanning.setString("InsHoldingsVarAnnuities", fPlanEntity.getInsholdingsvarannuities());
			fPlanning.setString("InsHoldingsImmediateAnnuities", fPlanEntity.getInsholdingsimmediateannuities());
			fPlanning.setString("RiskTolConservative", fPlanEntity.getRisktolconservative());
			fPlanning.setString("RiskTolModConservative", fPlanEntity.getRisktolmodconservative());
			fPlanning.setString("RiskTolModerate", fPlanEntity.getRisktolmoderate());
			fPlanning.setString("RiskTolModAggressive", fPlanEntity.getRisktolmodaggressive());
			fPlanning.setString("RiskTolAggressive", fPlanEntity.getRisktolaggressive());
			fPlanning.setString("SellInvestment", fPlanEntity.getSellinvestment());
			fPlanning.setString("FluctuationLot", fPlanEntity.getFluctuationlot());
			fPlanning.setString("FluctuationSome", fPlanEntity.getFluctuationsome());
			fPlanning.setString("FluctuationLittle", fPlanEntity.getFluctuationlittle());
			fPlanning.setString("FluctuationNone", fPlanEntity.getFluctuationnone());
			fPlanning.setString("InvestmentObjPOC", fPlanEntity.getInvestmentobjpoc());
			fPlanning.setString("InvestmentObjIncome", fPlanEntity.getInvestmentobjincome());
			fPlanning.setString("InvestmentObjModGrowth", fPlanEntity.getInvestmentobjmodgrowth());
			fPlanning.setString("InvestmentObjGrowth", fPlanEntity.getInvestmentobjgrowth());
			fPlanning.setString("InvestmentObjAggGrowth", fPlanEntity.getInvestmentobjagggrowth());
			fPlanning.setString("IncomeTaxBracketFifteen", fPlanEntity.getIncometaxbracketfifteen());
			fPlanning.setString("IncomeTaxBracketLessThanThirty", fPlanEntity.getIncometaxbracketlessthanthirty());
			fPlanning.setString("IncomeTaxBracketMoreThanThirty", fPlanEntity.getIncometaxbracketmorethanthirty());
			fPlanning.setString("IncomeTaxBracketUnsure", fPlanEntity.getIncometaxbracketunsure());
			fPlanning.setString("AnnInclessthanfifty", fPlanEntity.getAnninclessthanfifty());
			fPlanning.setString("AnnInclessthanOnefifty", fPlanEntity.getAnninclessthanonefifty());
			fPlanning.setString("AnnInclessthanTwofifty", fPlanEntity.getAnninclessthantwofifty());
			fPlanning.setString("AnnInclmorethantwofifty", fPlanEntity.getAnninclmorethantwofifty());
			fPlanning.setString("FinacialNeeds", fPlanEntity.getFinacialneeds());
			fPlanning.setString("FinacialNeedsUnsure", fPlanEntity.getFinacialneedsunsure());
			fPlanning.setString("HouseHoldLessThanFiveHundred", fPlanEntity.getHouseholdlessthanfivehundred());
			fPlanning.setString("HouseHoldLessThanOneThousand", fPlanEntity.getHouseholdlessthanonethousand());
			fPlanning.setString("HouseHoldMoreThanFiveHuundred", fPlanEntity.getHouseholdmorethanfivehuundred());
			fPlanning.setString("EmploymentAnticipated", fPlanEntity.getEmploymentanticipated());
			fPlanning.setString("EmploymentAnticipatedUnsure", fPlanEntity.getEmploymentanticipatedunsure());
			//fPlanning.setString("PremiumAmount", fPlanEntity.getPremiumamount());
			//fPlanning.setString("InsuredAmount", fPlanEntity.getInsuredamount());

		}
		return txLife;
	}


	/* (non-Javadoc)
	 * @see com.ibm.websphere.icp.insurance.life.reference.mock.impl.ServiceInterfaces#RetrieveProductProfiles(commonj.sdo.DataObject)
	 */
	@Override
	public DataObject RetrieveProductProfiles(DataObject retrieveProductProfiles) {
		BOHelper.debug("retrieveProductProfiles request:: "+retrieveProductProfiles);
		
		List boList = DBManager.getWicpDBManager().executeNamedQuery("getProducts", null);

		DataObject responseDO = BOHelper.createOrderTXLife();
		DataObject OLife = BOHelper.getFirstOLifE(responseDO, true, InsuranceConstants.ORDER_OLIFE_INDEX); 
		for (Iterator iterator = boList.iterator(); iterator.hasNext();) {
			Product bO = (Product) iterator.next();
			
			DataObject policyDO = BOHelper.boFactory.create(
					InsuranceConstants.EXTENSIONS_NS, "Policy_Type");
			policyDO.setString("ProductCode", String.valueOf(bO.getId()));
			policyDO.setString("PlanName", bO.getProductname());
			policyDO.setString("Description", bO.getProductdesc());
			OLife.createDataObject("Holding").set("Policy", policyDO);
		}
		return responseDO;
	}

	/* (non-Javadoc)
	 * @see com.ibm.websphere.icp.insurance.life.reference.mock.impl.ServiceInterfaces#UpdateCustomerApplicationData(commonj.sdo.DataObject)
	 */
	@Override
	public DataObject UpdateCustomerApplicationData(DataObject appDataRequest) {
		BOHelper.debug("in UpdateCustomerApplicationData");
		
		Financialplanning financialplanning = getFinancialPlanningEntity(appDataRequest); 
		BOHelper.debug("financialplanning--before saving ------"+financialplanning);
		
		if (financialplanning.getId() > 0) {
			DBManager.getWicpDBManager().update(financialplanning);
		} else {
			DBManager.getWicpDBManager().save(financialplanning);
		}
		BOHelper.debug("financialplanning:"+financialplanning.getId());
				
		DataObject appDataResponse = createTXLifeByNS(true, null, 0);
		DataObject resultInfo = ((DataObject)appDataResponse.getList(InsuranceConstants.TXLIFE_RESPONSE)
				.get(0))
				.createDataObject("TransResult")
				.createDataObject("ResultInfo");
		resultInfo.setString("ResultInfoDesc", "App data captured - no data persisted");
		
		return appDataResponse;
	}

	/**
	 * Creates the Financialplanning object with the data from the request.
	 * 
	 * @param appDataRequest
	 * @return
	 */
	private Financialplanning getFinancialPlanningEntity (
			DataObject appDataRequest) {
			BOHelper.debug(appDataRequest, "in getFinancialPlanningEntity");
		Financialplanning fPlanEntity = new Financialplanning();
		
		DataObject olife = BOHelper.getFirstOLifE(appDataRequest, false, InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX);
		DataObject client = ((DataObject)olife.getList("Party").get(0))
									.getDataObject("Client");
		DataObject fPlanning = 	client.getDataObject("FinancialPlaning");
		BOHelper.debug("fPlanning-----set into entity:"+fPlanning);
		String customerID = client.getString("CustomerID");
		BOHelper.debug("customerID:"+customerID);
		
		String formID = fPlanning.getString("ID");
		BOHelper.debug("formID:"+formID);
		if (formID != null) {
			fPlanEntity.setId(new Integer(formID)); 
		} else {
			Customer customer = new Customer();
			customer.setId(new Integer(customerID));		
			fPlanEntity.setCustomer(customer);
		}
		BOHelper.debug("fPlanning-------------:"+fPlanning);
		fPlanEntity.setPrimaryretirementincome(fPlanning.getString("PrimaryRetirementIncome"));
		fPlanEntity.setSupplementalincomeretirement(fPlanning.getString("SupplementalIncomeRetirement"));
		fPlanEntity.setAssetaccumulation(fPlanning.getString("AssetAccumulation"));
		fPlanEntity.setAccumulationforwealthtransfer(fPlanning.getString("AccumulationForWealthTransfer"));
		fPlanEntity.setDeathbenefit(fPlanning.getString("DeathBenefit"));
		fPlanEntity.setEnhanceddeathbenefit(fPlanning.getString("EnhancedDeathBenefit"));
		fPlanEntity.setSystematicwithdrawalbenifit(fPlanning.getString("SystematicWithdrawalBenifit"));
		fPlanEntity.setGuaranteedaccumulationbenefit(fPlanning.getString("GuaranteedAccumulationBenefit"));
		fPlanEntity.setGuaranteedincomerider(fPlanning.getString("GuaranteedIncomeRider"));
		fPlanEntity.setTimelestshanthreeyears(fPlanning.getString("TimeLestshanThreeYears"));
		fPlanEntity.setTimethreetofiveyears(fPlanning.getString("TimeThreeToFiveYears"));
		fPlanEntity.setTimefivetotenyears(fPlanning.getString("TimeFiveToTenYears"));
		fPlanEntity.setTimetenyears(fPlanning.getString("TimeTenYears"));
		fPlanEntity.setLifetime(fPlanning.getString("LifeTime"));
		fPlanEntity.setInvestmentexpnone(fPlanning.getString("InvestmentExpNone"));
		fPlanEntity.setInvestmentexplimited(fPlanning.getString("InvestmentExpLimited"));
		fPlanEntity.setInvestmentexpexperienced(fPlanning.getString("InvestmentExpExperienced"));
		fPlanEntity.setInvestmentexpextensive(fPlanning.getString("InvestmentExpExtensive"));
		fPlanEntity.setInvestlessthan25(fPlanning.getString("InvestLessThan25"));
		fPlanEntity.setInvestlessthan75(fPlanning.getString("InvestLessThan75"));
		fPlanEntity.setInvestlessthanonelakh(fPlanning.getString("InvestLessThanOneLakh"));
		fPlanEntity.setInvestmorethanonelakh(fPlanning.getString("InvestMoreThanOneLakh"));
		fPlanEntity.setQualifiedpuchase(fPlanning.getString("QualifiedPuchase"));
		fPlanEntity.setQualifiednonpuchase(fPlanning.getString("QualifiedNonPuchase"));
		fPlanEntity.setAddregularbasis(fPlanning.getString("AddRegularBasis"));
		fPlanEntity.setAddirregularbasis(fPlanning.getString("AddirRegularBasis"));
		fPlanEntity.setFundinvestmentexpnone(fPlanning.getString("FundInvestmentExpNone"));
		fPlanEntity.setInvestmentexpbonds(fPlanning.getString("InvestmentExpBonds"));
		fPlanEntity.setInvestmentexpfutures(fPlanning.getString("InvestmentExpFutures"));
		fPlanEntity.setInvestmentexpmutualfunds(fPlanning.getString("InvestmentExpMutualFunds"));
		fPlanEntity.setInvestmentexpannunities(fPlanning.getString("InvestmentExpAnnunities"));
		fPlanEntity.setInvestmentexpcds(fPlanning.getString("InvestmentExpCDs"));
		fPlanEntity.setInvestmentexpequities(fPlanning.getString("InvestmentExpEquities"));
		fPlanEntity.setInvestmentexpoptions(fPlanning.getString("InvestmentExpOptions"));
		fPlanEntity.setInvestmentexpindexedannunities(fPlanning.getString("InvestmentExpIndexedAnnunities"));
		fPlanEntity.setInvestmentexpfixedannunities(fPlanning.getString("InvestmentExpFixedAnnunities"));
		fPlanEntity.setInvestmentexpvarlifeins(fPlanning.getString("InvestmentExpVarLifeIns"));
		fPlanEntity.setSponsoredemployerprg(fPlanning.getString("SponsoredEmployerPrg"));
		fPlanEntity.setNonsponsoredemployerprg(fPlanning.getString("NonSponsoredEmployerPrg"));
		fPlanEntity.setMaxqualifiedplan(fPlanning.getString("MaxQualifiedPlan"));
		fPlanEntity.setMinqualifiedplan(fPlanning.getString("MinQualifiedPlan"));
		fPlanEntity.setNoqualifiedplan(fPlanning.getString("NoQualifiedPlan"));
		fPlanEntity.setInsholdingsamtoflifeins(fPlanning.getString("InsHoldingsAmtofLifeIns"));
		fPlanEntity.setInsholdingsplancashvalue(fPlanning.getString("InsHoldingsPlanCashValue"));
		fPlanEntity.setInsholdingsfixedannuities(fPlanning.getString("InsHoldingsFixedAnnuities"));
		fPlanEntity.setInsholdingsindexannuities(fPlanning.getString("InsHoldingsIndexAnnuities"));
		fPlanEntity.setInsholdingsvarannuities(fPlanning.getString("InsHoldingsVarAnnuities"));
		fPlanEntity.setInsholdingsimmediateannuities(fPlanning.getString("InsHoldingsImmediateAnnuities"));
		fPlanEntity.setRisktolconservative(fPlanning.getString("RiskTolConservative"));
		fPlanEntity.setRisktolmodconservative(fPlanning.getString("RiskTolModConservative"));
		fPlanEntity.setRisktolmoderate(fPlanning.getString("RiskTolModerate"));
		fPlanEntity.setRisktolmodaggressive(fPlanning.getString("RiskTolModAggressive"));
		fPlanEntity.setRisktolaggressive(fPlanning.getString("RiskTolAggressive"));
		fPlanEntity.setSellinvestment(fPlanning.getString("SellInvestment"));
		fPlanEntity.setFluctuationlot(fPlanning.getString("FluctuationLot"));
		fPlanEntity.setFluctuationsome(fPlanning.getString("FluctuationSome"));
		fPlanEntity.setFluctuationlittle(fPlanning.getString("FluctuationLittle"));
		fPlanEntity.setFluctuationnone(fPlanning.getString("FluctuationNone"));
		fPlanEntity.setInvestmentobjpoc(fPlanning.getString("InvestmentObjPOC"));
		fPlanEntity.setInvestmentobjincome(fPlanning.getString("InvestmentObjIncome"));
		fPlanEntity.setInvestmentobjmodgrowth(fPlanning.getString("InvestmentObjModGrowth"));
		fPlanEntity.setInvestmentobjgrowth(fPlanning.getString("InvestmentObjGrowth"));
		fPlanEntity.setInvestmentobjagggrowth(fPlanning.getString("InvestmentObjAggGrowth"));
		fPlanEntity.setIncometaxbracketfifteen(fPlanning.getString("IncomeTaxBracketFifteen"));
		fPlanEntity.setIncometaxbracketlessthanthirty(fPlanning.getString("IncomeTaxBracketLessThanThirty"));
		fPlanEntity.setIncometaxbracketmorethanthirty(fPlanning.getString("IncomeTaxBracketMoreThanThirty"));
		fPlanEntity.setIncometaxbracketunsure(fPlanning.getString("IncomeTaxBracketUnsure"));
		fPlanEntity.setAnninclessthanfifty(fPlanning.getString("AnnInclessthanfifty"));
		fPlanEntity.setAnninclessthanonefifty(fPlanning.getString("AnnInclessthanOnefifty"));
		fPlanEntity.setAnninclessthantwofifty(fPlanning.getString("AnnInclessthanTwofifty"));
		fPlanEntity.setAnninclmorethantwofifty(fPlanning.getString("AnnInclmorethantwofifty"));
		fPlanEntity.setFinacialneeds(fPlanning.getString("FinacialNeeds"));
		fPlanEntity.setFinacialneedsunsure(fPlanning.getString("FinacialNeedsUnsure"));
		fPlanEntity.setHouseholdlessthanfivehundred(fPlanning.getString("HouseHoldLessThanFiveHundred"));
		fPlanEntity.setHouseholdlessthanonethousand(fPlanning.getString("HouseHoldLessThanOneThousand"));
		fPlanEntity.setHouseholdmorethanfivehuundred(fPlanning.getString("HouseHoldMoreThanFiveHuundred"));
		fPlanEntity.setEmploymentanticipated(fPlanning.getString("EmploymentAnticipated"));
		fPlanEntity.setEmploymentanticipatedunsure(fPlanning.getString("EmploymentAnticipatedUnsure"));
		//fPlanEntity.setPremiumamount(fPlanning.getString("PremiumAmount"));
		//fPlanEntity.setInsuredamount(fPlanning.getString("InsuredAmount"));
		BOHelper.debug("fPlanEntity----------8888888---:"+fPlanEntity);
		return fPlanEntity;
	}

	/* (non-Javadoc)
	 * @see com.ibm.websphere.icp.insurance.life.reference.mock.impl.ServiceInterfaces#UpdateProductSelection(commonj.sdo.DataObject)
	 */
	@Override
	public DataObject UpdateProductSelection(DataObject productSelectionRequest) {
		BOHelper.debug("in UpdateProductSelection - DO nothing and log the product selection \n " +
				"persist this detail while order creation");
	
		DataObject productSelectionResponse = createTXLifeByNS(true, null, 0);
		DataObject resultInfo = ((DataObject)productSelectionResponse.getList(InsuranceConstants.TXLIFE_RESPONSE)
				.get(0))
				.createDataObject("TransResult")
				.createDataObject("ResultInfo");
	
		resultInfo.setString("ResultInfoDesc", "Product selection done - no data persisted");
		
		return productSelectionResponse;

	}
	
	/**
	 * Search customer from the database.
	 * 
	 * @param retrieveCustomerDetailsRequest {@link DataObject}
	 * @return {@link DataObject}
	 */
	private DataObject findCustomerBySearchCriteria (
			DataObject retrieveCustomerDetailsRequest) {
       
		BOHelper.debug("Inside searchCustomer operation of retrieveCustomerDetailsRequest");
        DataObject partyDO = null;
        DataObject personDO = null;
        DataObject addressDO = null;

        DataObject oLife = BOHelper.getFirstOLifE(retrieveCustomerDetailsRequest, false, InsuranceConstants.REQUEST_CUSTOMER_OLIFE_INDEX);
        if (oLife != null && oLife.getList("Party") != null &&
        		oLife.getList("Party").size() > 0) {
        	partyDO = (DataObject)oLife.getList("Party").get(0);
        	if (partyDO != null) {
        		personDO = partyDO.getDataObject("Person");
        		if (partyDO.getList("Address") != null && partyDO.getList("Address").size() > 0) {
        			addressDO = (DataObject)partyDO.getList("Address").get(0);
        		}
        	}
        }
        
        DataObject responseDO = BOHelper.createCustomerTXLife();
        if (personDO != null) {

            // assumption is at least one criteria will be available
            String queryString = "SELECT p FROM Person p ";

            StringBuilder sb = new StringBuilder();

            // search conditions list
            List<String> conditions = new ArrayList<String>();

            // query parameters map
            Map<String, Object> paramMap = new HashMap<String, Object>();
            
            String firstName = personDO.getString("FirstName");
            BOHelper.debug("personDO.getString(FirstName)"+personDO.getString("FirstName"));
            BOHelper.debug("personDO.get(FirstName)"+personDO.get("FirstName"));

            String lastName = personDO.getString("LastName");

            String suffix = null;
            if(personDO != null && 
            		personDO.getType() != null && 
            		personDO.getType().getURI() != null && 
            		personDO.getType().getURI().contains(InsuranceConstants.EXTENSIONS_NS)) {
            	suffix = partyDO.getString("Suffix");
            }
            	

            String gender = null;            
            if (personDO.getDataObject("Gender") != null){
            	gender = (String)personDO.getDataObject("Gender").get(0);
            }            
            
            Date dateOfBirth = personDO.getDate("BirthDate");

            // first name
            if (StringUtils.isNotEmpty(firstName)) {
                conditions.add("p.firstname LIKE :firstname");
                paramMap.put("firstname", "%" + firstName + "%");
            }

            // last name
            if (StringUtils.isNotEmpty(lastName)) {
                conditions.add("p.lastname LIKE :lastname");
                paramMap.put("lastname", "%" + lastName + "%");
            }

            // suffix
            if (suffix != null && StringUtils.isNotEmpty(suffix)) {
                conditions.add("p.suffix LIKE :suffix");
                paramMap.put("suffix", "%" + suffix + "%");
            }

            // gender
            if (gender != null && StringUtils.isNotEmpty(gender)) {
                conditions.add("p.gender = :gender");
                paramMap.put("gender", gender);
            }

            // date of birth
            if (dateOfBirth != null) {
                conditions.add("p.dob = :dob");
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                paramMap.put("dob", java.sql.Date.valueOf(sdf.format(dateOfBirth)));
            }

            if (addressDO != null) {
	            String address1 = addressDO.getString("Line1");
	
	            String address2 = addressDO.getString("Line2");
	
	            String city = addressDO.getString("City");
	            String state =  null;
	            if(addressDO != null && 
	            		addressDO.getType() != null && 
	            		addressDO.getType().getURI() != null && 
	            		addressDO.getType().getURI().contains(InsuranceConstants.EXTENSIONS_NS)) {
	            	state =  addressDO.getString("State");
	            }
	            
	            String zip = addressDO.getString("Zip");

	            // addressline1
	            if (StringUtils.isNotEmpty(address1)) {
	                conditions.add("p.address.address1 LIKE :address1");
	                paramMap.put("address1", "%" + address1 + "%");
	            }
	
	            // addressline2
	            if (StringUtils.isNotEmpty(address2)) {
	                conditions.add("p.address.address2 LIKE :address2");
	                paramMap.put("address2", "%" + address2 + "%");
	            }
	
	            // city
	            if (StringUtils.isNotEmpty(city)) {
	                conditions.add("p.address.city LIKE :city");
	                paramMap.put("city", "%" + city + "%");
	            }
	
	            // state
	            if (state != null &&  StringUtils.isNotEmpty(state)) {
	                conditions.add("p.address.state LIKE :state");
	                paramMap.put("state", "%" + state + "%");
	            }
	
	            // postal code
	            if (StringUtils.isNotEmpty(zip)) {
	                conditions.add("p.address.zip LIKE :zip");
	                paramMap.put("zip", "%" + zip + "%");
	            }
        	}

            int size = conditions.size();
            for (int i = 0; i < size; i++) {
                if (i == 0) {
                    sb.append(" WHERE ");
                } else {
                    sb.append(" AND ");
                }
                sb.append(conditions.get(i));
            }
            if (size > 0) {
            	sb.append(" AND ");
            } else {
            	sb.append(" WHERE ");
            }
            sb.append(" p.customer.id IS NOT NULL");
            // final query
            queryString = queryString + sb.toString();
            BOHelper.debug("final query string:" + queryString);
            
            List<BaseObject> customers = DBManager.getWicpDBManager().executeDynamicQuery(queryString, paramMap);
            DataObject responseOLifeDO = BOHelper.getFirstOLifE(responseDO, true, InsuranceConstants.CUSTOMER_OLIFE_INDEX);
            if (customers != null && !customers.isEmpty()) {
            	BOHelper.debug("customers.size():"+customers.size());
            	BOHelper.debug("customers:"+customers);
            	
                for (BaseObject customer : customers) {
                	partyDO = responseOLifeDO.createDataObject("Party", InsuranceConstants.EXTENSIONS_NS, "CustomerParty_Type");
                	personDO = partyDO.createDataObject("Person");                	
                    addressDO = partyDO.createDataObject("Address", InsuranceConstants.EXTENSIONS_NS, "Address_Type");

                    Person person = (Person)customer;                    
                    personDO.setString("FirstName", person.getFirstname());
                    personDO.setString("LastName", person.getLastname());
                    partyDO.setString("Suffix", person.getSuffix());
                    personDO.createDataObject("Gender").set(0, person.getGender());
                    personDO.setDate("BirthDate", person.getDob());
                    personDO.createDataObject("MarStat").set(0, person.getMaritalstatus());
                    
                    if (person.getAddress()!=null) {
                    	addressDO.setString("ID", String.valueOf(person.getAddress().getId()));
	                    addressDO.setString("Line1", person.getAddress().getAddress1());
	                    addressDO.setString("Line2", person.getAddress().getAddress2());
	                    addressDO.setString("City", person.getAddress().getCity());
	                    addressDO.setString("State", person.getAddress().getState());
	                    addressDO.setString("Zip", person.getAddress().getZip());
                    }
                    //partyDO                                        
                    partyDO.setString("Suffix", person.getSuffix());
                    partyDO.setString("SSN", person.getSsn());
                    partyDO.setString("SoldLocation", person.getSoldlocation());                      
                    partyDO.createDataObject("EMailAddress").setString("AddrLine", person.getEmail());
                    partyDO.setString("Citizenship", person.getCitizenship());                                        
                    partyDO.setString("SoldLocation", person.getSoldlocation());
                    partyDO.createDataObject("Phone").set(2, person.getMobile());                    
                    partyDO.setString("Citizenship", person.getCitizenship());
                    partyDO.createDataObject("Phone").set(2, person.getHometelephone());                    
                    
        			int customerId =person.getCustomer().getId();
        			BOHelper.debug("customerId: "+customerId);
        			DataObject clientDO = partyDO.createDataObject("Client", InsuranceConstants.EXTENSIONS_NS, "CustomerClient_Type");
        			clientDO.setString("CustomerID", String.valueOf(customerId));
                }

            }            
        }
        return responseDO;
	}

}
